@@ -11,9 +11,10 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.
 
-   You should have received a copy of the GNU Lesser General Public
-   License along with this library; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   You should have received a copy of the GNU Lesser General
+   Public License along with this library; if not, write to the
+   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301 USA */
 
 #if HAVE_CONFIG_H
 # include <config.h>
@@ -185,7 +186,7 @@ mu_check_tls_environment (void)
 	}
       if ((st.st_mode & S_IRWXG) || (st.st_mode & S_IRWXO))
 	{
-	  mu_error (_("Wrong permissions on %s. Set 0600."), ssl_key);
+	  mu_error (_("Wrong permissions on %s. Set 0600"), ssl_key);
 	  return 0;
 	}
     }
