@@ -13,7 +13,8 @@
 
    You should have received a copy of the GNU General Public License
    along with GNU Mailutils; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+   MA 02110-1301 USA */
 
 #include "comsat.h"
 #define obstack_chunk_alloc malloc
@@ -274,14 +275,14 @@ action_exec (FILE *tty, int line, int argc, char **argv)
 
   if (stat (argv[0], &stb))
     {
-      syslog (LOG_ERR, _("%s:.biffrc:%d: can't stat %s: %s"),
+      syslog (LOG_ERR, _("%s:.biffrc:%d: cannot stat %s: %s"),
 	      username, line, argv[0], strerror (errno));
       return;
     }
 
   if (stb.st_mode & (S_ISUID|S_ISGID))
     {
-      syslog (LOG_ERR, _("%s:.biffrc:%d: won't execute set[ug]id programs"),
+      syslog (LOG_ERR, _("%s:.biffrc:%d: will not execute set[ug]id programs"),
 	      username, line);
       return;
     }
@@ -295,7 +296,7 @@ action_exec (FILE *tty, int line, int argc, char **argv)
       dup2 (fileno (tty), 2);
       fclose (tty);
       execv (argv[0], argv);
-      syslog (LOG_ERR, _("can't execute %s: %s"), argv[0], strerror (errno));
+      syslog (LOG_ERR, _("Cannot execute %s: %s"), argv[0], strerror (errno));
       exit (0);
     }
 }
