@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2000, 2001 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2000, 2001, 2005 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -13,7 +13,8 @@
 
    You should have received a copy of the GNU General Public License
    along with GNU Mailutils; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+   MA 02110-1301 USA */
 
 /* This is a "fake" mta designed for testing purposes. It imitates
    sendmail sending and daemon modes. It does not actually send anything,
@@ -60,6 +61,7 @@
 #include <sys/socket.h>
 #include <netinet/in.h>
 #include <mu_asprintf.h>
+#include <getline.h>
 #include <mailutils/argcv.h>
 #include <mailutils/mailutils.h>
 
@@ -70,7 +72,6 @@ char *from_person = NULL; /* Set the name of the `from' person */
 int read_recipients = 0; /* Read the message for recipients */
 int dot = 1;             /* Message is terminated by a lone dot on a line */
 
-header_t header;
 address_t recipients = NULL;
 char *progname;
 
@@ -156,13 +157,6 @@ main (int argc, char **argv)
   domain = getenv ("MTA_DOMAIN");
   mu_set_user_email_domain (domain ? domain : "localhost");
   
-  if ((status = header_create (&header, NULL, 0, NULL)) != 0)
-    {
-      mu_error ("%s: can't create header: %s",
-		progname, mu_strerror (status));
-      return 1;
-    }
-
   argc -= optind;
   argv += optind;
   if (smtp_mode)
@@ -211,7 +205,6 @@ make_tmp (FILE *input, const char *from, char **tempfile)
 	  buf[len - 1] = 0;
 	}
 	  
-      //fprintf (diag, "%s", buf); //FM
       line++;
       if (line == 1)
 	{
@@ -279,10 +272,47 @@ add_recipient (const char *name)
   return status;
 }
 
+/* Convert addr to a comma-separated list of email addresses,
+   suitable as an argument to RCPT TO command */
+char *
+address_email_string (address_t addr)
+{
+  size_t count, i, n, length;
+  char *value, *p;
+  
+  address_get_email_count (addr, &count);
+  length = 0;
+  for (i = 1; i <= count; i++)
+    {
+      char *str;
+      address_aget_email (recipients, i, &str);
+      length += strlen (str) + 3;
+      free (str);
+    }
+
+  value = malloc (length + 1);
+  if (!value)
+    {
+      mu_error ("%s: not enough memory", progname);
+      return NULL;
+    }
+  p = value;
+  for (i = 1; i <= count; i++)
+    {
+      *p++ = '<';
+      address_get_email (recipients, i, p, length - (p - value), &n);
+      p += n;
+      *p++ = '>';
+      if (i + 1 <= count)
+	*p++ = ',';
+    }
+  *p = 0;
+  return value;
+}
+
 int
 mta_send (message_t msg)
 {
-  int c;
   size_t n;
   char buffer[512];    
   stream_t stream = NULL;
@@ -296,21 +326,7 @@ mta_send (message_t msg)
       free (value);
     }
   
-  c = address_to_string (recipients, NULL, 0, &n);
-  if (c)
-    {
-      mu_error ("%s: address_to_string failure: %s",
-		progname, mu_strerror (c));
-      return 1;
-    }
-  value = malloc (n + 1);
-  if (!value)
-    {
-      mu_error ("%s: not enough memory", progname);
-      return 1;
-    }
-
-  address_to_string (recipients, value, n + 1, &n);
+  value = address_email_string (recipients);
   fprintf (diag, "ENVELOPE TO: %s\n", value);
   free (value);
 
@@ -555,7 +571,6 @@ smtp (int fd)
       
       if (getline (&buf, &size, in) == -1)
 	exit (1);
-      //fprintf (diag, "%s", buf); //FM
       len = strlen (buf);
       while (len > 0 && (buf[len-1] == '\n' || buf[len-1] == '\r'))
 	len --;
