@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2001, 2002, 2003 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2001, 2002, 2003, 2004 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -13,9 +13,13 @@
 
    You should have received a copy of the GNU General Public License
    along with GNU Mailutils; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+   MA 02110-1301 USA */
 
 #include "imap4d.h"
+#ifdef WITH_GSASL
+# include <mailutils/gsasl.h>
+#endif
 
 mailbox_t mbox;
 char *homedir;
@@ -28,25 +32,33 @@ struct daemon_param daemon_param = {
   20,				/* Default maximum number of children */
   143,				/* Standard IMAP4 port */
   1800,				/* RFC2060: 30 minutes. */
-  0				/* No transcript by default */
+  0,				/* No transcript by default */
+  NULL                          /* No PID file by default */
 };
 
-int login_disabled;
+int login_disabled;             /* Disable LOGIN command */
+int tls_required;               /* Require STARTTLS */
 
 /* Number of child processes.  */
-volatile size_t children;
+size_t children;
 
 const char *program_version = "imap4d (" PACKAGE_STRING ")";
 static char doc[] = N_("GNU imap4d -- the IMAP4D daemon");
 
 #define ARG_LOGIN_DISABLED 1
+#define ARG_TLS_REQUIRED   2
+
 static struct argp_option options[] = {
   {"other-namespace", 'O', N_("PATHLIST"), 0,
-   N_("set the `other' namespace"), 0},
+   N_("Set the `other' namespace"), 0},
   {"shared-namespace", 'S', N_("PATHLIST"), 0,
-   N_("set the `shared' namespace"), 0},
+   N_("Set the `shared' namespace"), 0},
   {"login-disabled", ARG_LOGIN_DISABLED, NULL, 0,
    N_("Disable LOGIN command")},
+#ifdef WITH_TLS
+  {"tls-required", ARG_TLS_REQUIRED, NULL, 0,
+   N_("Always require STARTTLS before entering authentication phase")},
+#endif
   {NULL, 0, NULL, 0, NULL, 0}
 };
 
@@ -101,8 +113,15 @@ imap4d_parse_opt (int key, char *arg, struct argp_state *state)
 
     case ARG_LOGIN_DISABLED:
       login_disabled = 1;
-      imap4d_capability_add ("LOGINDISABLED");
+      imap4d_capability_add (IMAP_CAPA_LOGINDISABLED);
       break;
+
+#ifdef WITH_TLS
+    case ARG_TLS_REQUIRED:
+      tls_required = 1;
+      imap4d_capability_add (IMAP_CAPA_XTLSREQUIRED);
+      break;
+#endif
       
     default:
       return ARGP_ERR_UNKNOWN;
@@ -165,13 +184,8 @@ main (int argc, char **argv)
     }
 
   /* Register the desired formats. */
-  {
-    list_t bookie;
-    registrar_get_list (&bookie);
-    list_append (bookie, mbox_record);
-    list_append (bookie, path_record);
-  }
-
+  mu_register_local_mbox_formats ();
+  
   /* Set the signal handlers.  */
   signal (SIGINT, imap4d_signal);
   signal (SIGQUIT, imap4d_signal);
@@ -202,6 +216,11 @@ main (int argc, char **argv)
 
   umask (S_IROTH | S_IWOTH | S_IXOTH);	/* 007 */
 
+  if (daemon_param.pidfile)
+    {
+      daemon_create_pidfile (daemon_param.pidfile);
+    }
+
   /* Check TLS environment, i.e. cert and key files */
 #ifdef WITH_TLS
   starttls_init ();
@@ -240,10 +259,10 @@ imap4d_mainloop (int fd, FILE *infile, FILE *outfile)
 
       syslog (LOG_INFO, _("Incoming connection opened"));
       if (getpeername (fd, (struct sockaddr *) &cs, &len) < 0)
-	syslog (LOG_ERR, _("can't obtain IP address of client: %s"),
+	syslog (LOG_ERR, _("Cannot obtain IP address of client: %s"),
 		strerror (errno));
       else
-	syslog (LOG_INFO, _("connect from %s"), inet_ntoa (cs.sin_addr));
+	syslog (LOG_INFO, _("Connect from %s"), inet_ntoa (cs.sin_addr));
       text = "IMAP4rev1";
     }
   else
@@ -280,7 +299,7 @@ imap4d_daemon_init (void)
      first three one, in, out, err   */
   if (daemon (0, 0) < 0)
     {
-      perror (_("fork failed"));
+      perror (_("could not become daemon"));
       exit (1);
     }
 
@@ -310,7 +329,7 @@ imap4d_daemon (unsigned int maxchildren, unsigned int port)
   int listenfd, connfd;
   size_t size;
 
-  listenfd = socket (AF_INET, SOCK_STREAM, 0);
+  listenfd = socket (PF_INET, SOCK_STREAM, 0);
   if (listenfd == -1)
     {
       syslog (LOG_ERR, "socket: %s", strerror (errno));
@@ -336,11 +355,13 @@ imap4d_daemon (unsigned int maxchildren, unsigned int port)
       exit (1);
     }
 
+  syslog (LOG_INFO, _("GNU imap4d started"));
+
   for (;;)
     {
       if (children > maxchildren)
 	{
-	  syslog (LOG_ERR, _("too many children (%lu)"),
+	  syslog (LOG_ERR, _("Too many children (%lu)"),
 		  (unsigned long) children);
 	  pause ();
 	  continue;
