@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2001, 2002, 2003 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2001, 2002, 2003, 2004, 2005 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -13,7 +13,8 @@
 
    You should have received a copy of the GNU General Public License
    along with GNU Mailutils; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+   MA 02110-1301 USA */
 
 #ifndef _IMAP4D_H
 #define _IMAP4D_H 1
@@ -23,10 +24,10 @@
 #endif
 
 #define _QNX_SOURCE
-#define _GNU_SOURCE
 
+#include <sys/types.h>
 #ifdef HAVE_SECURITY_PAM_APPL_H
-#include <security/pam_appl.h>
+# include <security/pam_appl.h>
 #endif
 
 #ifdef HAVE_SHADOW_H
@@ -72,23 +73,28 @@
 #include <mailutils/argp.h>
 #include <mailutils/attribute.h>
 #include <mailutils/body.h>
+#include <mailutils/daemon.h>
 #include <mailutils/envelope.h>
 #include <mailutils/errno.h>
 #include <mailutils/error.h>
 #include <mailutils/filter.h>
 #include <mailutils/folder.h>
 #include <mailutils/header.h>
+#include <mailutils/iterator.h>
 #include <mailutils/list.h>
 #include <mailutils/mailbox.h>
 #include <mailutils/message.h>
 #include <mailutils/mutil.h>
+#include <mailutils/mu_auth.h>
+#include <mailutils/nls.h>
 #include <mailutils/parse822.h>
 #include <mailutils/registrar.h>
 #include <mailutils/stream.h>
-#include <mailutils/mu_auth.h>
-#include <mailutils/url.h>
 #include <mailutils/tls.h>
-#include <mailutils/nls.h>
+#include <mailutils/url.h>
+
+#include <mu_asprintf.h>
+#include <getline.h>
 
 #ifdef __cplusplus
 extern "C" {
@@ -122,13 +128,14 @@ struct imap4d_command
 #define RESP_NONE	4
 
 /* Error values.  */
-#define OK 0
-#define ERR_NO_MEM 1
-#define ERR_NO_OFILE 2
-#define ERR_TIMEOUT 3
-#define ERR_SIGNAL 4
-#define ERR_TLS 5
-
+#define OK                    0
+#define ERR_NO_MEM            1
+#define ERR_NO_OFILE          2
+#define ERR_TIMEOUT           3
+#define ERR_SIGNAL            4
+#define ERR_TLS               5
+#define ERR_MAILBOX_CORRUPTED 6
+  
 /* Namespace numbers */
 #define NS_PRIVATE 0
 #define NS_OTHER   1
@@ -139,18 +146,24 @@ struct imap4d_command
 #define WCARD_NOMATCH        0
 #define WCARD_MATCH          1
 #define WCARD_RECURSE_MATCH  2
-       
+
+/*  IMAP4D capability names */
+#define IMAP_CAPA_STARTTLS       "STARTTLS"
+#define IMAP_CAPA_LOGINDISABLED  "LOGINDISABLED"
+#define IMAP_CAPA_XTLSREQUIRED   "XTLSREQUIRED"  
+  
 extern struct imap4d_command imap4d_command_table[];
 extern mailbox_t mbox;
 extern char *homedir;
 extern char *rootdir;
 extern int state;
-extern volatile size_t children;
+extern size_t children;
 extern int is_virtual;
 extern struct daemon_param daemon_param;
 extern struct mu_auth_data *auth_data; 
 
 extern int login_disabled;
+extern int tls_required;
 
 #ifndef HAVE_STRTOK_R
 extern char *strtok_r __P((char *s, const char *delim, char **save_ptr));
@@ -204,7 +217,8 @@ extern void fetch_flags0 (const char *prefix, message_t msg, int isuid);
 extern int imap4d_sync __P ((void));
 extern int imap4d_sync_flags __P ((size_t));
 extern size_t uid_to_msgno __P ((size_t));
-
+extern void imap4d_set_observer (mailbox_t mbox);
+  
 /* Signal handling.  */
 extern RETSIGTYPE imap4d_sigchld __P ((int));
 extern RETSIGTYPE imap4d_signal __P ((int));
