@@ -13,7 +13,8 @@
 
    You should have received a copy of the GNU General Public License
    along with GNU Mailutils; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+   MA 02110-1301 USA */
 
 #include "imap4d.h"
 
@@ -42,7 +43,7 @@ imap4d_login (struct imap4d_command *command, char *arg)
 
   if (auth_data == NULL)
     {
-      syslog (LOG_INFO, _("User '%s': nonexistent"), username);
+      syslog (LOG_INFO, _("User `%s': nonexistent"), username);
       return util_finish (command, RESP_NO, "User name or passwd rejected");
     }
 
@@ -60,7 +61,7 @@ imap4d_login (struct imap4d_command *command, char *arg)
   homedir = mu_normalize_path (strdup (auth_data->dir), "/");
   chdir (homedir);
   namespace_init (homedir);
-  syslog (LOG_INFO, _("User '%s' logged in"), username);
+  syslog (LOG_INFO, _("User `%s' logged in"), username);
   return util_finish (command, RESP_OK, "Completed");
 }
 
