@@ -13,7 +13,8 @@
 
    You should have received a copy of the GNU General Public License
    along with GNU Mailutils; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+   MA 02110-1301 USA */
 
 #include "imap4d.h"
 
@@ -142,7 +143,7 @@ imap4d_store0 (char *arg, int isuid, char *resp, size_t resplen)
 	{
 	  util_send ("* %d FETCH (", msgno);
 	  fetch_flags0 ("FLAGS", msg, isuid);
-	  util_send (")\n");
+	  util_send (")\r\n");
 	}
       free (p);
       /* Update the flags of uid table.  */
