@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2001, 2002, 2003 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2001, 2002, 2003, 2004 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -13,7 +13,8 @@
 
    You should have received a copy of the GNU General Public License
    along with GNU Mailutils; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+   MA 02110-1301 USA */
 
 #include "imap4d.h"
 
@@ -199,13 +200,14 @@ util_msgset (char *s, size_t ** set, int *n, int isuid)
 	  {
 	    errno = 0;
 	    val = strtoul (s, &s, 10);
-	    if (val == ULONG_MAX && errno == ERANGE)
+	    if ((val == ULONG_MAX && errno == ERANGE) || val > max)
 	      {
 		if (*set)
 		  free (*set);
 		*n = 0;
 		return EINVAL;
 	      }
+	    
 	    if (low)
 	      {
 		/* Reverse it. */
@@ -400,26 +402,40 @@ util_out (int rc, const char *format, ...)
 int
 util_finish (struct imap4d_command *command, int rc, const char *format, ...)
 {
-  char *tempbuf = NULL;
+  size_t size;
   char *buf = NULL;
+  char *tempbuf = NULL;
   int new_state;
   int status = 0;
   va_list ap;
-
-  asprintf (&tempbuf, "%s %s%s %s\r\n", command->tag, sc2string (rc),
-	    command->name, format);
+  char *sc = sc2string (rc);
+  
   va_start (ap, format);
-  vasprintf (&buf, tempbuf, ap);
+  vasprintf (&tempbuf, format, ap);
   va_end (ap);
+  if (!tempbuf)
+    imap4d_bye (ERR_NO_MEM);
+  
+  size = strlen (command->tag) + 1 +
+         strlen (sc) + strlen (command->name) + 1 +
+         strlen (tempbuf) + 1;
+  buf = malloc (size);
   if (!buf)
     imap4d_bye (ERR_NO_MEM);
+  strcpy (buf, command->tag);
+  strcat (buf, " ");
+  strcat (buf, sc);
+  strcat (buf, command->name);
+  strcat (buf, " ");
+  strcat (buf, tempbuf);
+  free (tempbuf);
 
   if (daemon_param.transcript)
-    syslog (LOG_DEBUG, "sent: %s", buf);
+    syslog (LOG_DEBUG, "sent: %s\r\n", buf);
 
-  status = stream_sequential_write (ostream, buf, strlen (buf));
+  stream_sequential_write (ostream, buf, strlen (buf));
   free (buf);
-  free (tempbuf);
+  stream_sequential_write (ostream, "\r\n", 2);
 
   /* Reset the state.  */
   if (rc == RESP_OK)
@@ -466,16 +482,16 @@ imap4d_readline (void)
       rc = stream_sequential_readline (istream, buffer, sizeof (buffer), &sz);
       if (sz == 0)
 	{
-	  syslog (LOG_INFO, _("unexpected eof on input"));
+	  syslog (LOG_INFO, _("Unexpected eof on input"));
 	  imap4d_bye (ERR_NO_OFILE);
 	}
       else if (rc)
 	{
-	  char *p;
+	  const char *p;
 	  if (stream_strerror (istream, &p))
 	    p = strerror (errno);
 
-	  syslog (LOG_INFO, _("error reading from input file: %s"), p);
+	  syslog (LOG_INFO, _("Error reading from input file: %s"), p);
 	  imap4d_bye (ERR_NO_OFILE);
 	}
       alarm (0);
@@ -887,10 +903,10 @@ util_base64_encode (const unsigned char *input, size_t input_len,
     {
       unsigned char c = (input[0] << 4) & 0x30;
       *out++ = b64tab[input[0] >> 2];
-      if (input_len > 0)
+      if (input_len > 1)
 	c |= input[1] >> 4;
       *out++ = b64tab[c];
-      *out++ = (input_len < 2) ? '-' : b64tab[(input[1] << 2) & 0x3c];
+      *out++ = (input_len < 2) ? '=' : b64tab[(input[1] << 2) & 0x3c];
       *out++ = '=';
     }
   *output_len = out - *output;
@@ -962,7 +978,7 @@ util_localname ()
 	}
       if (status)
 	{
-	  syslog (LOG_CRIT, _("Can't find out my own hostname"));
+	  syslog (LOG_CRIT, _("Cannot find out my own hostname"));
 	  exit (1);
 	}
 
@@ -1084,16 +1100,12 @@ util_get_output (stream_t *pstr)
 void
 util_set_input (stream_t str)
 {
-  if (istream)
-    stream_destroy (&istream, stream_get_owner (istream));
   istream = str;
 }
 
 void
 util_set_output (stream_t str)
 {
-  if (ostream)
-    stream_destroy (&ostream, stream_get_owner (ostream));
   ostream = str;
 }
 
@@ -1104,30 +1116,20 @@ util_set_output (stream_t str)
 int
 util_wait_input (int timeout)
 {
-  int rc, fd;
-  fd_set rdset;
+  int wflags = MU_STREAM_READY_RD;
+  struct timeval tv;
+  int status;
   
-  if (stream_get_fd (istream, &fd))
+  tv.tv_sec = timeout;
+  tv.tv_usec = 0;
+  status = stream_wait (istream, &wflags, &tv);
+  if (status)
     {
-      errno = ENOSYS;
+      syslog (LOG_ERR, _("Cannot poll input stream: %s"),
+	      mu_strerror(status));
       return -1;
     }
-
-  FD_ZERO (&rdset);
-  FD_SET (fd, &rdset);
-
-  do
-    {
-      struct timeval tv;
-
-      tv.tv_sec = timeout;
-      tv.tv_usec = 0;
-      
-      rc = select (fd + 1, &rdset, NULL, NULL, &tv);
-    }
-  while (rc == -1 && errno == EINTR);
-
-  return rc;
+  return wflags & MU_STREAM_READY_RD;
 }
 
 void
@@ -1147,27 +1149,20 @@ int
 imap4d_init_tls_server ()
 {
   stream_t stream;
-  int in_fd;
-  int out_fd;
   int rc;
-  
-  if (stream_get_fd (istream, &in_fd)
-      || stream_get_fd (ostream, &out_fd))
-    return 0;
-  rc = tls_stream_create (&stream, in_fd, out_fd, 0);
+ 
+  rc = tls_stream_create (&stream, istream, ostream, 0);
   if (rc)
     return 0;
 
   if (stream_open (stream))
     {
-      char *p;
+      const char *p;
       stream_strerror (stream, &p);
-      syslog (LOG_ERR, _("cannot open TLS stream: %s"), p);
+      syslog (LOG_ERR, _("Cannot open TLS stream: %s"), p);
       return 0;
     }
 
-  stream_destroy (&istream, stream_get_owner (istream));
-  stream_destroy (&ostream, stream_get_owner (ostream));
   istream = ostream = stream;
   return 1;
 }
@@ -1258,7 +1253,7 @@ util_run_events (int old_state, int new_state)
       ev.old_state = old_state;
       ev.new_state = new_state;
 
-      iterator_create (&itr, event_list);
+      list_get_iterator (event_list, &itr);
       for (iterator_first (itr); !iterator_is_done (itr); iterator_next (itr))
 	{
 	  struct state_event *p;
