@@ -11,9 +11,10 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.
 
-   You should have received a copy of the GNU Lesser General Public
-   License along with this library; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   You should have received a copy of the GNU Lesser General
+   Public License along with this library; if not, write to the
+   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301 USA */
 
 #ifndef _MAILUTILS_NLS_H
 #define _MAILUTILS_NLS_H
@@ -38,6 +39,7 @@
 #else
 # define _(String) (String)
 # define N_(String) String
+# define gettext(msgid) (msgid)
 # define dgettext(domain, msgid) (msgid)
 # define ngettext(sg,pl,cnt) (cnt == 1) ? (sg) : (pl)
 # define textdomain(Domain)
