@@ -11,9 +11,10 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.
 
-   You should have received a copy of the GNU Lesser General Public
-   License along with this library; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   You should have received a copy of the GNU Lesser General
+   Public License along with this library; if not, write to the
+   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301 USA */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -88,22 +89,26 @@ instr_run (sieve_machine_t mach)
 void
 instr_action (sieve_machine_t mach)
 {
+  mach->identifier = SIEVE_ARG (mach, 3, string);
   if (INSTR_DEBUG (mach))
     sieve_debug (mach, "%4lu: ACTION: %s\n",
 		 (unsigned long) (mach->pc - 1),
-		 SIEVE_ARG (mach, 3, string));
+		 mach->identifier);
   mach->action_count++;
   instr_run (mach);
+  mach->identifier = NULL;
 }
 
 void
 instr_test (sieve_machine_t mach)
 {
+  mach->identifier = SIEVE_ARG (mach, 3, string);
   if (INSTR_DEBUG (mach))
     sieve_debug (mach, "%4lu: TEST: %s\n",
 		 (unsigned long) (mach->pc - 1),
-		 SIEVE_ARG (mach, 3, string));
+		 mach->identifier);
   mach->reg = instr_run (mach);
+  mach->identifier = NULL;
 }
 
 void
@@ -118,7 +123,7 @@ instr_push (sieve_machine_t mach)
   
   if (!mach->stack && list_create (&mach->stack))
     {
-      sieve_error (mach, _("can't create stack"));
+      sieve_error (mach, _("cannot create stack"));
       sieve_abort (mach);
     }
   list_prepend (mach->stack, (void*) mach->reg);
@@ -254,6 +259,12 @@ sieve_get_debug_level (sieve_machine_t mach)
   return mach->debug_level;
 }
 
+const char *
+sieve_get_identifier (sieve_machine_t mach)
+{
+  return mach->identifier;
+}
+
 int
 sieve_is_dry_run (sieve_machine_t mach)
 {
