@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2000, 2001, 2002 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2000, 2001, 2002, 2005 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -13,7 +13,8 @@
 
    You should have received a copy of the GNU General Public License
    along with GNU Mailutils; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+   MA 02110-1301 USA */
 
 #include <mail.local.h>
 
@@ -55,9 +56,10 @@ N_("GNU mail.local -- the local MDA\
 \v\
 Debug flags are:\n\
   g - guimb stack traces\n\
-  T - mailutil traces (MU_DEBUG_TRACE)\n\
+  T - mailutils traces (MU_DEBUG_TRACE)\n\
   P - network protocols (MU_DEBUG_PROT)\n\
   t - sieve trace (MU_SIEVE_DEBUG_TRACE)\n\
+  i - sieve instructions trace (MU_SIEVE_DEBUG_INSTR)\n\
   l - sieve action logs\n\
   0-9 - Set mail.local debugging level\n");
 
@@ -71,7 +73,7 @@ static char args_doc[] = N_("recipient [recipient ...]");
 static struct argp_option options[] = 
 {
   { "ex-multiple-delivery-success", ARG_MULTIPLE_DELIVERY, NULL, 0,
-    N_("Don't return errors when delivering to multiple recipients"), 0 },
+    N_("Do not return errors when delivering to multiple recipients"), 0 },
   { "ex-quota-tempfail", ARG_QUOTA_TEMPFAIL, NULL, 0,
     N_("Return temporary failure if disk or mailbox quota is exceeded"), 0 },
   { "from", 'f', N_("EMAIL"), 0,
@@ -86,12 +88,12 @@ static struct argp_option options[] =
     N_("SQL query to retrieve mailbox quota"), 0 },
 #endif
   { "sieve", 'S', N_("PATTERN"), 0,
-    N_("Set name pattern for user-defined sieve mail filters"), 0 },
+    N_("Set name pattern for user-defined Sieve mail filters"), 0 },
   { "message-id-header", ARG_MESSAGE_ID_HEADER, N_("STRING"), 0,
     N_("Identify messages by the value of this header when logging Sieve actions"), 0 },
 #ifdef WITH_GUILE
   { "source", 's', N_("PATTERN"), 0,
-    N_("Set name pattern for user-defined mail filters"), 0 },
+    N_("Set name pattern for user-defined Scheme mail filters"), 0 },
 #endif
   { "debug", 'x', N_("FLAGS"), 0,
     N_("Enable debugging"), 0 },
@@ -151,7 +153,7 @@ parse_opt (int key, char *arg, struct argp_state *state)
     case 'f':
       if (from != NULL)
 	{
-	  argp_error (state, _("multiple --from options"));
+	  argp_error (state, _("Multiple --from options"));
 	  return EX_USAGE;
 	}
       from = arg;
@@ -165,20 +167,20 @@ parse_opt (int key, char *arg, struct argp_state *state)
 
 #ifdef WITH_GUILE	
     case 's':
-      progfile_pattern = optarg;
+      progfile_pattern = arg;
       break;
 #endif
 
     case 'S':
-      sieve_pattern = optarg;
+      sieve_pattern = arg;
       break;
       
     case 'x':
       do
 	{
-	  if (!optarg)
-	    optarg = D_DEFAULT;
-	  switch (*optarg)
+	  if (!arg)
+	    arg = D_DEFAULT;
+	  switch (*arg)
 	    {
 	    case 'g':
 #ifdef WITH_GUILE
@@ -190,6 +192,10 @@ parse_opt (int key, char *arg, struct argp_state *state)
 	      sieve_debug_flags |= MU_SIEVE_DEBUG_TRACE;
 	      break;
 
+	    case 'i':
+	      sieve_debug_flags |= MU_SIEVE_DEBUG_INSTR;
+	      break;
+	      
 	    case 'l':
 	      sieve_enable_log = 1;
 	      break;
@@ -203,14 +209,14 @@ parse_opt (int key, char *arg, struct argp_state *state)
 	      break;
 
 	    default:
-	      if (isdigit (*optarg))
-		debug_level = *optarg - '0';
+	      if (isdigit (*arg))
+		debug_level = *arg - '0';
 	      else
 		argp_error (state, _("%c is not a valid debug flag"), *arg);
 	      break;
 	    }
 	}
-      while (*++optarg);
+      while (*++arg);
       break;
       
     default:
@@ -414,7 +420,7 @@ sieve_test (struct mu_auth_data *auth, mailbox_t mbx)
   if (access (progfile, R_OK))
     {
       if (debug_level > 2)
-	syslog (LOG_DEBUG, _("access to %s failed: %m"), progfile);
+	syslog (LOG_DEBUG, _("Access to %s failed: %m"), progfile);
     }
   else
     {
@@ -422,7 +428,7 @@ sieve_test (struct mu_auth_data *auth, mailbox_t mbx)
       rc = sieve_machine_init (&mach, auth->name);
       if (rc)
 	{
-	  mu_error (_("can't initialize sieve machine: %s"),
+	  mu_error (_("Cannot initialize sieve machine: %s"),
 		    mu_strerror (rc));
 	}
       else
@@ -543,7 +549,7 @@ make_tmp (const char *from, mailbox_t *mbox)
   tempfile = mu_tempname (NULL);
   if ((status = file_stream_create (&stream, tempfile, MU_STREAM_RDWR)))
     {
-      mailer_err (_("unable to open temporary file: %s"), mu_strerror (status));
+      mailer_err (_("Unable to open temporary file: %s"), mu_strerror (status));
       exit (exit_code);
     }
 
@@ -580,7 +586,7 @@ make_tmp (const char *from, mailbox_t *mbox)
 		}
 	      else
 		{
-		  mailer_err (_("Can't determine sender address"));
+		  mailer_err (_("Cannot determine sender address"));
 		  exit (EX_UNAVAILABLE);
 		}
 	      if (auth)
@@ -598,7 +604,7 @@ make_tmp (const char *from, mailbox_t *mbox)
       
       if (status)
 	{
-	  mailer_err (_("temporary file write error: %s"), mu_strerror (status));
+	  mailer_err (_("Error writing temporary file: %s"), mu_strerror (status));
 	  stream_destroy (&stream, stream_get_owner (stream));
 	  return status;
 	}
@@ -615,7 +621,7 @@ make_tmp (const char *from, mailbox_t *mbox)
   if (status)
     {
       errno = status;
-      mailer_err (_("temporary file write error: %s"), mu_strerror (status));
+      mailer_err (_("Error writing temporary file: %s"), mu_strerror (status));
       stream_destroy (&stream, stream_get_owner (stream));
       return status;
     }
@@ -625,7 +631,7 @@ make_tmp (const char *from, mailbox_t *mbox)
       || (status = mailbox_open (*mbox, MU_STREAM_READ))
       || (status = mailbox_set_stream (*mbox, stream)))
     {
-      mailer_err (_("temporary file open error: %s"), mu_strerror (status));
+      mailer_err (_("Error opening temporary file: %s"), mu_strerror (status));
       stream_destroy (&stream, stream_get_owner (stream));
       return status;
     }
@@ -634,7 +640,7 @@ make_tmp (const char *from, mailbox_t *mbox)
   if (status)
     {
       errno = status;
-      mailer_err (_("temporary message creation error: %s"),
+      mailer_err (_("Error creating temporary message: %s"),
 		  mu_strerror (status));
       stream_destroy (&stream, stream_get_owner (stream));
       return status;
@@ -673,14 +679,15 @@ deliver (mailbox_t imbx, char *name)
 
   if ((status = mailbox_get_stream (imbx, &istream)) != 0)
     {
-      mailer_err (_("can't get input message stream: %s"), mu_strerror (status));
+      mailer_err (_("Cannot get input message stream: %s"),
+		  mu_strerror (status));
       mu_auth_data_free (auth);
       return;
     }
   
   if ((status = mailbox_create (&mbox, auth->mailbox)) != 0)
     {
-      mailer_err (_("can't open mailbox %s: %s"),
+      mailer_err (_("Cannot open mailbox %s: %s"),
 		  auth->mailbox, mu_strerror (status));
       mu_auth_data_free (auth);
       return;
@@ -699,7 +706,7 @@ deliver (mailbox_t imbx, char *name)
     return;
   if (status != 0)
     {
-      mailer_err (_("can't open mailbox %s: %s"), path, mu_strerror (status));
+      mailer_err (_("Cannot open mailbox %s: %s"), path, mu_strerror (status));
       mailbox_destroy (&mbox);
       return;
     }
@@ -710,7 +717,7 @@ deliver (mailbox_t imbx, char *name)
 
   if (status)
     {
-      mailer_err (_("cannot lock mailbox '%s': %s"), path, mu_strerror (status));
+      mailer_err (_("Cannot lock mailbox `%s': %s"), path, mu_strerror (status));
       mailbox_destroy (&mbox);
       exit_code = EX_TEMPFAIL;
       return;
@@ -718,7 +725,7 @@ deliver (mailbox_t imbx, char *name)
 
   if ((status = mailbox_get_stream (mbox, &ostream)))
     {
-      mailer_err (_("can't get stream for mailbox %s: %s"),
+      mailer_err (_("Cannot get stream for mailbox %s: %s"),
 		  path, mu_strerror (status));
       mailbox_destroy (&mbox);
       return;
@@ -726,7 +733,7 @@ deliver (mailbox_t imbx, char *name)
 
   if ((status = stream_size (ostream, &size)))
     {
-      mailer_err (_("can't get stream size (mailbox %s): %s"),
+      mailer_err (_("Cannot get stream size (mailbox %s): %s"),
 		  path, mu_strerror (status));
       mailbox_destroy (&mbox);
       return;
@@ -751,7 +758,7 @@ deliver (mailbox_t imbx, char *name)
       default:
 	if ((status = stream_size (istream, &isize)))
 	  {
-	    mailer_err (_("can't get stream size (input message): %s"),
+	    mailer_err (_("Cannot get stream size (input message): %s"),
 			path, mu_strerror (status));
 	    exit_code = EX_UNAVAILABLE;
 	    failed++;
@@ -811,10 +818,10 @@ deliver (mailbox_t imbx, char *name)
 	     original size */
 	  int rc = stream_truncate (ostream, size);
 	  if (rc)
-	    mailer_err (_("error writing to mailbox: %s. Mailbox NOT truncated: %s"),
+	    mailer_err (_("Error writing to mailbox: %s. Mailbox NOT truncated: %s"),
 			mu_strerror (status), mu_strerror (rc));
 	  else  
-	    mailer_err (_("error writing to mailbox: %s"),
+	    mailer_err (_("Error writing to mailbox: %s"),
 	  	        mu_strerror (status));
 	}
     }
