@@ -1,5 +1,6 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2000, 2001, 2002, 2003 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2000, 2001, 2002, 2003, 
+   2005 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -13,7 +14,8 @@
 
    You should have received a copy of the GNU General Public License
    along with GNU Mailutils; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+   MA 02110-1301 USA */
 
 #include "mail.h"
 
@@ -30,9 +32,9 @@ struct decode_closure
 
 static int print_stream __P ((stream_t, FILE *));
 static int display_message __P ((message_t, msgset_t *msgset, void *closure));
-static int display_message0 __P ((FILE *, message_t, const msgset_t *, int));
-static int mailcap_lookup __P ((const char *));
+static int display_message0 __P ((message_t, const msgset_t *, int));
 static int get_content_encoding __P ((header_t hdr, char **value));
+static void run_metamail __P((const char *mailcap, message_t mesg));
 
 int
 mail_decode (int argc, char **argv)
@@ -54,34 +56,19 @@ mail_decode (int argc, char **argv)
 int
 display_message (message_t mesg, msgset_t *msgset, void *arg)
 {
-  FILE *out;
-  size_t lines = 0;
   struct decode_closure *closure = arg;
-  int pagelines = util_get_crt ();
   attribute_t attr = NULL;
 
   message_get_attribute (mesg, &attr);
   if (attribute_is_deleted (attr))
     return 1;
 
-  message_lines (mesg, &lines);
-  if (pagelines && lines > pagelines)
-    out = popen (getenv ("PAGER"), "w");
-  else
-    out = ofile;
-
-  display_message0 (out, mesg, msgset, closure->select_hdr);
-
-  if (out != ofile)
-    pclose (out);
+  display_message0 (mesg, msgset, closure->select_hdr);
 
   /* Mark enclosing message as read */
   if (mailbox_get_message (mbox, msgset->msg_part[0], &mesg) == 0)
-    {
-      attribute_t attr;
-      message_get_attribute (mesg, &attr);
-      attribute_set_read (attr);
-    }
+    util_mark_read (mesg);
+
   return 0;
 }
 
@@ -142,7 +129,7 @@ display_part_header (FILE *out, const msgset_t *msgset,
   fprintf (out, "\n");
 
   fprintf (out, _("| Type=%s\n"), type);
-  fprintf (out, _("| encoding=%s\n"), encoding);
+  fprintf (out, _("| Encoding=%s\n"), encoding);
   fputc ('+', out);
   for (i = 0; (int)i <= size; i++)
     fputc ('-', out);
@@ -151,14 +138,15 @@ display_part_header (FILE *out, const msgset_t *msgset,
 }
 
 static int
-display_message0 (FILE *out, message_t mesg, const msgset_t *msgset,
+display_message0 (message_t mesg, const msgset_t *msgset,
 		  int select_hdr)
 {
   size_t nparts = 0;
   header_t hdr = NULL;
-  char *type;
+  const char *type;
   char *encoding;
   int ismime = 0;
+  char *tmp;
 
   message_get_header (mesg, &hdr);
   util_get_content_type (hdr, &type);
@@ -168,7 +156,7 @@ display_message0 (FILE *out, message_t mesg, const msgset_t *msgset,
   if (ismime)
     {
       unsigned int j;
-
+      
       message_get_num_parts (mesg, &nparts);
 
       for (j = 1; j <= nparts; j++)
@@ -179,7 +167,7 @@ display_message0 (FILE *out, message_t mesg, const msgset_t *msgset,
 	    {
 	      msgset_t *set = msgset_expand (msgset_dup (msgset),
 					     msgset_make_1 (j));
-	      display_message0 (out, message, set, 0);
+	      display_message0 (message, set, 0);
 	      msgset_free (set);
 	    }
 	}
@@ -189,40 +177,73 @@ display_message0 (FILE *out, message_t mesg, const msgset_t *msgset,
       message_t submsg = NULL;
 
       if (message_unencapsulate (mesg, &submsg, NULL) == 0)
-	display_message0 (out, submsg, msgset, select_hdr);
+	display_message0 (submsg, msgset, select_hdr);
     }
-  else if (mailcap_lookup (type))
+  else if (util_getenv (&tmp, "metamail", Mail_env_string, 0) == 0)
     {
-      /* FIXME: lookup .mailcap and do the appropriate action when
-	 an match engry is find.  */
-      /* Do something, spawn a process etc ....  */
+      /* If `metamail' is set to a string, treat it as command line
+	 of external metamail program. */
+      run_metamail (tmp, mesg);
     }
-  else /*if (strncasecmp (type, "text/plain", strlen ("text/plain")) == 0
-	 || strncasecmp (type, "text/html", strlen ("text/html")) == 0)*/
+  else
     {
+      int builtin_display = 1;
       body_t body = NULL;
       stream_t b_stream = NULL;
+      stream_t d_stream = NULL;
+      stream_t stream = NULL;
+      header_t hdr = NULL;
+      
+      message_get_body (mesg, &body);
+      message_get_header (mesg, &hdr);
+      body_get_stream (body, &b_stream);
 
-      display_part_header (out, msgset, type, encoding);
-      display_headers (out, mesg, msgset, select_hdr);
+      /* Can we decode.  */
+      if (filter_create(&d_stream, b_stream, encoding,
+			MU_FILTER_DECODE, MU_STREAM_READ) == 0)
+	stream = d_stream;
+      else
+	stream = b_stream;
 
-      if (message_get_body (mesg, &body) == 0 &&
-	  body_get_stream (body, &b_stream) == 0)
+      display_part_header (ofile, msgset, type, encoding);
+
+      /* If `metamail' is set to true, enable internal mailcap
+	 support */
+      if (util_getenv (NULL, "metamail", Mail_env_boolean, 0) == 0)
 	{
-	  stream_t d_stream = NULL;
-	  stream_t stream = NULL;
+	  char *no_ask = NULL;
+	  int debug = 0;
+	  
+	  util_getenv (&no_ask, "mimenoask", Mail_env_string, 0);
+	  if (util_getenv (&debug, "verbose", Mail_env_boolean, 0) == 0
+	      && debug)
+	    debug = 9;
+	  
+	  builtin_display = display_stream_mailcap (NULL, stream, hdr, no_ask,
+						    interactive, 0, debug);
+	}
 
-	  /* Can we decode.  */
-	  if (filter_create(&d_stream, b_stream, encoding,
-			    MU_FILTER_DECODE, MU_STREAM_READ) == 0)
-	    stream = d_stream;
+      if (builtin_display)
+	{
+	  size_t lines = 0;
+	  int pagelines = util_get_crt ();
+	  FILE *out;
+	  
+	  message_lines (mesg, &lines);
+	  if (pagelines && lines > pagelines)
+	    out = popen (getenv ("PAGER"), "w");
 	  else
-	    stream = b_stream;
+	    out = ofile;
+
+	  display_headers (out, mesg, msgset, select_hdr);
 
 	  print_stream (stream, out);
-	  if (d_stream)
-	    stream_destroy (&d_stream, NULL);
+
+	  if (out != ofile)
+	    pclose (out);
 	}
+      if (d_stream)
+	stream_destroy (&d_stream, NULL);
     }
 
   free (type);
@@ -268,9 +289,111 @@ get_content_encoding (header_t hdr, char **value)
   return 0;
 }
 
-
-static int
-mailcap_lookup (const char *type ARG_UNUSED)
+/* Run `metamail' program MAILCAP_CMD on the message MESG */
+static void
+run_metamail (const char *mailcap_cmd, message_t mesg)
 {
-  return 0;
+  pid_t pid;
+  struct sigaction ignore;
+  struct sigaction saveintr;
+  struct sigaction savequit;
+  sigset_t chldmask;
+  sigset_t savemask;
+  
+  ignore.sa_handler = SIG_IGN;	/* ignore SIGINT and SIGQUIT */
+  ignore.sa_flags = 0;
+  sigemptyset (&ignore.sa_mask);
+  if (sigaction (SIGINT, &ignore, &saveintr) < 0)
+    {
+      util_error ("sigaction: %s", strerror (errno));
+      return;
+    }      
+  if (sigaction (SIGQUIT, &ignore, &savequit) < 0)
+    {
+      util_error ("sigaction: %s", strerror (errno));
+      sigaction (SIGINT, &saveintr, NULL);
+      return;
+    }      
+      
+  sigemptyset (&chldmask);	/* now block SIGCHLD */
+  sigaddset (&chldmask, SIGCHLD);
+
+  if (sigprocmask (SIG_BLOCK, &chldmask, &savemask) < 0)
+    {
+      sigaction (SIGINT, &saveintr, NULL);
+      sigaction (SIGQUIT, &savequit, NULL);
+      return;
+    }
+  
+  pid = fork ();
+  if (pid < 0)
+    {
+      util_error ("fork: %s", strerror (errno));
+    }
+  else if (pid == 0)
+    {
+      /* Child process */
+      int status;
+      stream_t stream;
+
+      do /* Fake loop to avoid gotos */
+	{
+	  stream_t pstr;
+	  char buffer[512];
+	  size_t n;
+	  char *no_ask;
+	  
+	  setenv ("METAMAIL_PAGER", getenv ("PAGER"), 0);
+	  if (util_getenv (&no_ask, "mimenoask", Mail_env_string, 0))
+	    setenv ("MM_NOASK", no_ask, 1);
+	  
+	  status = message_get_stream (mesg, &stream);
+	  if (status)
+	    {
+	      mu_error ("message_get_stream: %s", mu_strerror (status));
+	      break;
+	    }
+
+	  status = prog_stream_create (&pstr, mailcap_cmd, MU_STREAM_WRITE);
+	  if (status)
+	    {
+	      mu_error ("prog_stream_create: %s", mu_strerror (status));
+	      break;
+	    }
+
+	  status = stream_open (pstr);
+	  if (status)
+	    {
+	      mu_error ("stream_open: %s", mu_strerror (status));
+	      break;
+	    }
+	  
+	  while (stream_sequential_read (stream,
+					 buffer, sizeof buffer - 1,
+					 &n) == 0
+		 && n > 0)
+	    stream_sequential_write (pstr, buffer, n);
+
+	  stream_close (pstr);
+	  stream_destroy (&pstr, stream_get_owner (pstr));
+	  exit (0);
+	}
+      while (0);
+      
+      abort ();
+    }
+  else
+    {
+      int status;
+      /* Master process */
+      
+      while (waitpid (pid, &status, 0) < 0)
+	if (errno != EINTR)
+	  break;
+    }
+
+  /* Restore the signal handlers */
+  sigaction (SIGINT, &saveintr, NULL);
+  sigaction (SIGQUIT, &savequit, NULL);
+  sigprocmask (SIG_SETMASK, &savemask, NULL);
 }
