@@ -13,7 +13,8 @@
 
    You should have received a copy of the GNU General Public License
    along with GNU Mailutils; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+   MA 02110-1301 USA */
 
 #include "mail.h"
 
@@ -52,7 +53,7 @@ _cond_push(int val)
 
   if (!_cond_stack)
     {
-      util_error(_("not enough memory"));
+      util_error(_("Not enough memory"));
       exit (EXIT_FAILURE);
     }
   _cond_stack[_cond_level++] = val;
@@ -63,7 +64,7 @@ _cond_pop()
 {
   if (_cond_level == 0)
     {
-      util_error(_("internal error: condition stack underflow"));
+      util_error(_("Internal error: condition stack underflow"));
       abort();
     }
   return _cond_stack[--_cond_level];
@@ -85,13 +86,14 @@ mail_if (int argc, char **argv)
 
   if (argc != 2)
     {
+      /* TRANSLATORS: 'if' is the function name. Do not translate it */
       util_error(_("if requires an argument: s | r | t"));
       return 1;
     }
 
   if (argv[1][1] != 0)
     {
-      util_error(_("valid if arguments are: s | r | t"));
+      util_error(_("Valid if arguments are: s | r | t"));
       return 1;
     }
 
@@ -111,11 +113,11 @@ mail_if (int argc, char **argv)
 	case 'r': /* Read mode */
 	  cond = strcmp(mode, "send") != 0;
 	  break;
-	case 't': /* Reading from a terminal */
-	  cond = interactive;
+	case 't': /* Stdout is a terminal device? */
+	  cond = isatty (fileno (stdout));
 	  break;
 	default:
-	  util_error(_("valid if arguments are: s | r | t"));
+	  util_error(_("Valid if arguments are: s | r | t"));
 	  return 1;
 	}
     }
@@ -131,6 +133,7 @@ mail_else (int argc ARG_UNUSED, char **argv ARG_UNUSED)
 
   if (_cond_level == 0)
     {
+      /* TRANSLATORS: 'else' and 'if' are function names. Do not translate them */
       util_error(_("else without matching if"));
       return 1;
     }
@@ -146,6 +149,7 @@ mail_endif (int argc ARG_UNUSED, char **argv ARG_UNUSED)
 {
   if (_cond_level == 0)
     {
+      /* TRANSLATORS: 'endif' and 'if' are function names. Do not translate them */
       util_error(_("endif without matching if"));
       return 1;
     }
