@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2000, 2001, 2002 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2000, 2001, 2002, 2005 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -13,7 +13,8 @@
 
    You should have received a copy of the GNU General Public License
    along with GNU Mailutils; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+   MA 02110-1301 USA */
 
 #ifndef _MAIL_H
 #define _MAIL_H 1
@@ -327,6 +328,8 @@ void util_run_cached_commands __P((list_t *list));
 const char *util_reply_prefix __P((void));
 void util_rfc2047_decode __P((char **value));
 
+void util_mark_read __P((message_t msg));
+
 extern int ml_got_interrupt __P ((void));
 extern void ml_clear_interrupt __P ((void));
 extern void ml_readline_init __P ((void));
@@ -369,6 +372,7 @@ extern char *readline __P ((char *prompt));
 #define MAIL_ATTRIBUTE_MBOXED   0x0001
 #define MAIL_ATTRIBUTE_SAVED    0x0002
 #define MAIL_ATTRIBUTE_TAGGED   0x0004
+#define MAIL_ATTRIBUTE_SHOWN    0x0008
 
 #ifdef __cplusplus
 }
