@@ -233,10 +233,10 @@ static const short yycheck[] = {    14,
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.  */
+   You should have received a copy of the GNU General Public
+   License along with this program; if not, write to the Free
+   Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301 USA.  */
 
 /* As a special exception, when this file is copied by Bison into a
    Bison output file, you may use that output file without restriction.
@@ -1592,13 +1592,12 @@ select_body (message_t msg, void *closure)
 }
 
 int
-select_sender (message_t msg, void *closure)
+select_sender (message_t msg ARG_UNUSED, void *closure ARG_UNUSED)
 {
   /* char *sender = (char*) closure; */
   /* FIXME: all messages from sender argv[i] */
   /* Annoying we can use address_create() for that
      but to compare against what? The email ?  */
-  (void)msg; (void)closure;
   return 0;
 }
 
@@ -1631,12 +1630,11 @@ select_type (message_t msg, void *closure)
 }
 
 int
-select_deleted (message_t msg, void *closure)
+select_deleted (message_t msg, void *closure ARG_UNUSED)
 {
   attribute_t attr= NULL;
   int rc;
 
-  (void)closure;
   message_get_attribute (msg, &attr);
   rc = attribute_is_deleted (attr);
   return strcmp (xargv[0], "undelete") == 0 ? rc : !rc;
