@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2000, 2001, 2002 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2000, 2001, 2002, 2005 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -13,7 +13,8 @@
 
    You should have received a copy of the GNU General Public License
    along with GNU Mailutils; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+   MA 02110-1301 USA */
 
 #include "mail.h"
 
@@ -36,7 +37,7 @@ mail_print_msg (msgset_t *mspec, message_t mesg, void *data)
   FILE *out = ofile;
   attribute_t attr;
   int pagelines = util_get_crt ();
-      
+  
   message_lines (mesg, &lines);
 
   /* If it is POP or IMAP the lines number is not known, so try
@@ -103,8 +104,7 @@ mail_print_msg (msgset_t *mspec, message_t mesg, void *data)
   if (out != ofile)
     pclose (out);
   
-  message_get_attribute (mesg, &attr);
-  attribute_set_read (attr);
+  util_mark_read (mesg);
 
   cursor = mspec->msg_part[0];
   
