@@ -13,7 +13,8 @@
 
    You should have received a copy of the GNU General Public License
    along with GNU Mailutils; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+   MA 02110-1301 USA */
 
 #include "mail.h"
 
@@ -62,10 +63,16 @@ mail_execute (int shell, int argc, char **argv)
 {
   pid_t pid;
   char *buf = NULL;
+  char *argv0 = NULL;
 
-  /* Skip leading whitespace from argv[0] */
-  while (isspace (**argv))
-    (*argv)++;
+  if (argc)
+    {
+      argv0 = argv[0]; 
+  
+      /* Skip leading whitespace from argv[0] */
+      while (isspace (**argv))
+	(*argv)++;
+    }
 
   /* Expand arguments if required */
   if (util_getenv (NULL, "bang", Mail_env_boolean, 0) == 0)
@@ -77,7 +84,7 @@ mail_execute (int shell, int argc, char **argv)
     }
 
   /* Construct command line and save it to gnu-last-command variable */
-  argcv_string (argc, &argv[0], &buf);
+  argcv_string (argc, argv, &buf);
   util_setenv ("gnu-last-command", buf, Mail_env_string, 1);
 
   /* Do actual work */
@@ -111,18 +118,22 @@ mail_execute (int shell, int argc, char **argv)
       execvp (argv[0], argv);
       exit (1);
     }
-  else if (pid > 0)
+  else
     {
+      if (argv0) /* Restore argv[0], else argcv_free will coredump */
+	argv[0] = argv0;
       free (buf);
-      while (waitpid (pid, NULL, 0) == -1)
-	/* do nothing */;
-      return 0;
-    }
-  else if (pid < 0)
-    {
-      free (buf);
-      mu_error ("fork failed: %s", mu_strerror (errno));
-      return 1;
+      if (pid > 0)
+	{
+	  while (waitpid (pid, NULL, 0) == -1)
+	    /* do nothing */;
+	  return 0;
+	}
+      else /* if (pid < 0) */
+	{
+	  mu_error ("fork failed: %s", mu_strerror (errno));
+	  return 1;
+	}
     }
 }
 
