@@ -1,6 +1,6 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
    Copyright (C) 1999, 2000, 2001, 2002, 2003,
-   2004 Free Software Foundation, Inc.
+   2004, 2005 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -14,7 +14,8 @@
 
    You should have received a copy of the GNU General Public License
    along with GNU Mailutils; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+   MA 02110-1301 USA */
 
 #include "mail.h"
 #include <mailutils/mutil.h>
@@ -121,7 +122,7 @@ util_do_command (const char *c, ...)
 	    return 0;
 	}
 
-      if (argcv_get (cmd, delim, NULL, &argc, &argv) == 0)
+      if (argcv_get (cmd, delim, NULL, &argc, &argv) == 0 && argc > 0)
 	{
 	  struct mail_command_entry entry;
 	  char *p;
@@ -152,9 +153,13 @@ util_do_command (const char *c, ...)
     }
   else
     {
-      util_error (_("Unknown command: %s"), argv[0]);
+      if (argc)
+	util_error (_("Unknown command: %s"), argv[0]);
+      else
+	util_error (_("Invalid command"));
       status = 1;
     }
+      
 
   argcv_free (argc, argv);
   return status;
@@ -600,6 +605,16 @@ util_isdeleted (size_t n)
   return attribute_is_deleted (attr);
 }
 
+void
+util_mark_read (message_t msg)
+{
+  attribute_t attr;
+
+  message_get_attribute (msg, &attr);
+  attribute_set_read (attr);
+  attribute_set_userflag (attr, MAIL_ATTRIBUTE_SHOWN);
+}
+
 char *
 util_get_homedir ()
 {
@@ -607,7 +622,7 @@ util_get_homedir ()
   if (!homedir)
     {
       /* Shouldn't happen, but one never knows */
-      util_error (_("can't get homedir"));
+      util_error (_("Cannot get homedir"));
       exit (EXIT_FAILURE);
     }
   return homedir;
@@ -669,14 +684,14 @@ util_get_sender (int msgno, int strip)
       if (envelope_sender (env, buffer, sizeof (buffer), NULL)
 	  || address_create (&addr, buffer))
 	{
-	  util_error (_("can't determine sender name (msg %d)"), msgno);
+	  util_error (_("Cannot determine sender name (msg %d)"), msgno);
 	  return NULL;
 	}
     }
 
   if (address_aget_email (addr, 1, &buf))
     {
-      util_error (_("can't determine sender name (msg %d)"), msgno);
+      util_error (_("Cannot determine sender name (msg %d)"), msgno);
       address_destroy (&addr);
       return NULL;
     }
@@ -698,7 +713,7 @@ util_slist_print (list_t list, int nl)
   iterator_t itr;
   char *name;
 
-  if (!list || iterator_create (&itr, list))
+  if (!list || list_get_iterator (list, &itr))
     return;
 
   for (iterator_first (itr); !iterator_is_done (itr); iterator_next (itr))
@@ -717,7 +732,7 @@ util_slist_lookup (list_t list, char *str)
   char *name;
   int rc = 0;
 
-  if (!list || iterator_create (&itr, list))
+  if (!list || list_get_iterator (list, &itr))
     return 0;
 
   for (iterator_first (itr); !iterator_is_done (itr); iterator_next (itr))
@@ -743,7 +758,7 @@ util_slist_add (list_t *list, char *value)
 
   if ((p = strdup(value)) == NULL)
     {
-      util_error(_("not enough memory\n"));
+      util_error(_("Not enough memory"));
       return;
     }
   list_append (*list, p);
@@ -773,7 +788,7 @@ util_slist_destroy (list_t *list)
   iterator_t itr;
   char *name;
 
-  if (!*list || iterator_create (&itr, *list))
+  if (!*list || list_get_iterator (*list, &itr))
     return;
 
   for (iterator_first (itr); !iterator_is_done (itr); iterator_next (itr))
@@ -792,7 +807,7 @@ util_slist_to_string (list_t list, const char *delim)
   char *name;
   char *str = NULL;
 
-  if (!list || iterator_create (&itr, list))
+  if (!list || list_get_iterator (list, &itr))
     return NULL;
 
   for (iterator_first (itr); !iterator_is_done (itr); iterator_next (itr))
@@ -919,7 +934,7 @@ util_save_outgoing (message_t msg, char *savefile)
       outfile = fopen (filename, "a");
       if (!outfile)
 	{
-	  util_error(_("can't open save file %s: %s"),
+	  util_error(_("Cannot open save file %s: %s"),
 		     filename, strerror (errno));
 	}
       else
@@ -936,7 +951,7 @@ util_save_outgoing (message_t msg, char *savefile)
 
 	  if (!bsize)
 	    {
-	      util_error(_("not enough memory for creating save file"));
+	      util_error(_("Not enough memory for creating save file"));
 	    }
 	  else
 	    {
@@ -1046,7 +1061,7 @@ util_descend_subparts (message_t mesg, msgset_t *msgset, message_t *part)
 	{
 	  if (message_unencapsulate (mesg, &submsg, NULL))
 	    {
-	      util_error (_("can't unencapsulate message/part"));
+	      util_error (_("Cannot unencapsulate message/part"));
 	      return 1;
 	    }
 	  mesg = submsg;
@@ -1055,14 +1070,14 @@ util_descend_subparts (message_t mesg, msgset_t *msgset, message_t *part)
       message_get_num_parts (mesg, &nparts);
       if (nparts < msgset->msg_part[i])
 	{
-	  util_error (_("no such (sub)part in the message: %d"),
+	  util_error (_("No such (sub)part in the message: %d"),
 		      msgset->msg_part[i]);
 	  return 1;
 	}
 
       if (message_get_part (mesg, msgset->msg_part[i], &submsg))
 	{
-	  util_error (_("can't get (sub)part from the message: %d"),
+	  util_error (_("Cannot get (sub)part from the message: %d"),
 		      msgset->msg_part[i]);
 	  return 1;
 	}
@@ -1186,7 +1201,7 @@ util_header_expand (header_t *phdr)
   rc = header_create (&hdr, "", 0, NULL);
   if (rc)
     {
-      util_error (_("can't create temporary header: %s"), mu_strerror (rc));
+      util_error (_("Cannot create temporary header: %s"), mu_strerror (rc));
       return 1;
     }
       
@@ -1227,10 +1242,10 @@ util_header_expand (header_t *phdr)
 		{
 		  errcnt++;
 		  if (exp)
-		    util_error (_("can't parse address `%s' (while expanding `%s'): %s"),
+		    util_error (_("Cannot parse address `%s' (while expanding `%s'): %s"),
 				exp, p, mu_strerror (rc));
 		  else
-		    util_error (_("can't parse address `%s': %s"),
+		    util_error (_("Cannot parse address `%s': %s"),
 				p, mu_strerror (rc));
 		}
 	      
@@ -1283,7 +1298,7 @@ util_get_message (mailbox_t mbox, size_t msgno, message_t *msg)
   status = mailbox_get_message (mbox, msgno, msg);
   if (status)
     {
-      util_error (_("can't get message %lu: %s"),
+      util_error (_("Cannot get message %lu: %s"),
 		  (unsigned long) msgno, mu_strerror (status));
       return status;
     }
@@ -1338,14 +1353,18 @@ util_run_cached_commands (list_t *list)
 void
 util_rfc2047_decode (char **value)
 {
+  char locale[32];
   char *charset = NULL;
   char *tmp;
   int rc;
 
   if (!*value || util_getenv (&charset, "charset", Mail_env_string, 0))
     return;
+
   if (strcasecmp (charset, "auto") == 0)
     {
+      memset (locale, 0, sizeof (locale));
+
       /* Try to deduce the charset from LC_ALL or LANG variables */
 
       tmp = getenv ("LC_ALL");
@@ -1358,7 +1377,9 @@ util_rfc2047_decode (char **value)
 	  char *lang;
 	  char *terr;
 
-	  lang = strtok_r (tmp, "_", &sp);
+	  strncpy (locale, tmp, sizeof (locale) - 1);
+
+	  lang = strtok_r (locale, "_", &sp);
 	  terr = strtok_r (NULL, ".", &sp);
 	  charset = strtok_r (NULL, "@", &sp);
 
@@ -1374,7 +1395,7 @@ util_rfc2047_decode (char **value)
   if (rc)
     {
       if (util_getenv (NULL, "verbose", Mail_env_boolean, 0) == 0)
-	mu_error (_("Can't decode line `%s': %s"), *value, mu_strerror (rc));
+	mu_error (_("Cannot decode line `%s': %s"), *value, mu_strerror (rc));
     }
   else
     {
@@ -1382,3 +1403,4 @@ util_rfc2047_decode (char **value)
       *value = tmp;
     }
 }
+
