@@ -13,7 +13,8 @@
 
    You should have received a copy of the GNU General Public License
    along with GNU Mailutils; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+   MA 02110-1301 USA */
 
 #include "mail.h"
 
@@ -84,7 +85,7 @@ z_parse_args(int argc, char **argv,
 	{
 	  if (dir == D_NONE)
 	    {
-	      util_error (_("argument not applicable for z."));
+	      util_error (_("Argument not applicable for z"));
 	      return 1;
 	    }
 
