@@ -11,9 +11,10 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.
 
-   You should have received a copy of the GNU Lesser General Public
-   License along with this library; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   You should have received a copy of the GNU Lesser General
+   Public License along with this library; if not, write to the
+   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301 USA */
 
 #include <ctype.h>
 
@@ -61,10 +62,11 @@ argcv_scan (int len, const char *command, const char *delim, const char* cmnt,
 	 /*FALLTHRU*/ default:
 	  if (isdelim (command[i], delim))
 	    break;
-	  /* Skip until next whitespace character or end of line */
+	  /* Skip until next whitespace character or end of line. Honor
+	     escaped whitespace. */
 	  while (++i < len &&
-		 !(isws (command[i]) || isdelim (command[i], delim)))
-	    ;
+		 !((isws (command[i]) && command[i-1] != '\\')
+		   || isdelim (command[i], delim)));
 	  i--;
 	  break;
 	}
@@ -117,7 +119,7 @@ argcv_escape_char (int c)
       if (*p == c)
 	return p[-1];
     }
-  return c;
+  return -1;
 }
   
 
@@ -259,7 +261,7 @@ escape_copy (char *dst, const char *src)
 	  else
 	    {
 	      char tmp[4];
-	      snprintf (tmp, sizeof tmp, "%03o", *src);
+	      snprintf (tmp, sizeof tmp, "%03o", *(unsigned char*)src);
 	      memcpy (dst, tmp, 3);
 	      dst += 3;
 	    }
