@@ -11,9 +11,10 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.
 
-   You should have received a copy of the GNU Lesser General Public
-   License along with this library; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   You should have received a copy of the GNU Lesser General
+   Public License along with this library; if not, write to the
+   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301 USA */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -282,6 +283,7 @@ authenticate_imap_sasl_anon (authority_t auth)
       return ENOSYS;
     }
 
+  /* FIXME: auth_state is never set explicitely before this function */
   switch (f_imap->auth_state)
     {
     case IMAP_AUTH_ANON_REQ_WRITE:
@@ -292,13 +294,13 @@ authenticate_imap_sasl_anon (authority_t auth)
 				 f_imap->seq);
 	f_imap->seq++;
 	CHECK_ERROR_CLOSE (folder, f_imap, status);
-	f_imap->state = IMAP_AUTH_ANON_REQ_SEND;
+	f_imap->auth_state = IMAP_AUTH_ANON_REQ_SEND;
       }
 
     case IMAP_AUTH_ANON_REQ_SEND:
       status = imap_send (f_imap);
       CHECK_EAGAIN (f_imap, status);
-      f_imap->state = IMAP_AUTH_ANON_WAIT_CONT;
+      f_imap->auth_state = IMAP_AUTH_ANON_WAIT_CONT;
 
     case IMAP_AUTH_ANON_WAIT_CONT:
       status = imap_parse (f_imap);
@@ -306,25 +308,25 @@ authenticate_imap_sasl_anon (authority_t auth)
       FOLDER_DEBUG0 (folder, MU_DEBUG_PROT, f_imap->buffer);
       if (strncmp ("+", f_imap->buffer, 2) == 0)
 	{
-	  f_imap->state = IMAP_AUTH_ANON_MSG;
+	  f_imap->auth_state = IMAP_AUTH_ANON_MSG;
 	}
       else
 	{
 	  /* Something is wrong! */
 	}
-      f_imap->state = IMAP_AUTH_ANON_MSG;
+      f_imap->auth_state = IMAP_AUTH_ANON_MSG;
 
     case IMAP_AUTH_ANON_MSG:
       FOLDER_DEBUG0 (folder, MU_DEBUG_PROT, "\n");
       status = imap_writeline (f_imap, "\r\n");
       CHECK_ERROR_CLOSE (folder, f_imap, status);
-      f_imap->state = IMAP_AUTH_ANON_MSG_SEND;
+      f_imap->auth_state = IMAP_AUTH_ANON_MSG_SEND;
 
     case IMAP_AUTH_ANON_MSG_SEND:
       status = imap_send (f_imap);
       CHECK_EAGAIN (f_imap, status);
 
-      f_imap->state = IMAP_AUTH_ANON_WAIT_RESP;
+      f_imap->auth_state = IMAP_AUTH_ANON_WAIT_RESP;
 
     case IMAP_AUTH_ANON_WAIT_RESP:
       status = imap_parse (f_imap);
@@ -371,9 +373,9 @@ authenticate_imap_select (authority_t auth)
   folder_t folder = authority_get_owner (auth);
   f_imap_t f_imap = folder->data;
   struct auth_tab *p;
-  int status = MU_ERR_AUTH_FAILURE;
+  int status = ENOSYS;
   
-  for (p = auth_tab; status && p->name; p++)
+  for (p = auth_tab; status == ENOSYS && p->name; p++)
     {
       f_imap->state = IMAP_AUTH;
       status = p->method (auth);
@@ -2474,8 +2476,10 @@ imap_parse (f_imap_t f_imap)
 		  status = MU_ERR_AUTH_FAILURE;
 		}
 	      else
-		status = EINVAL;
-	      mu_error ("NO/Bad Tagged: %s %s\n", response, remainder);
+		{
+		  status = EINVAL;
+		  mu_error ("NO/Bad Tagged: %s %s\n", response, remainder);
+		}
 	    }
 	}
       f_imap->ptr = f_imap->buffer;
