@@ -13,10 +13,10 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.  */
+   You should have received a copy of the GNU General Public
+   License along with this program; if not, write to the Free
+   Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301 USA.  */
 
 /* As a special exception, when this file is copied by Bison into a
    Bison output file, you may use that output file without restriction.
@@ -109,7 +109,8 @@
 
    You should have received a copy of the GNU General Public License
    along with GNU Mailutils; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+   MA 02110-1301 USA */
   
 /* A heavily modified version of the well-known public domain getdate.y.
    It was originally written by Steven M. Bellovin <smb@research.att.com>
@@ -223,7 +224,7 @@ struct pd_date
   int ordinal;
 };
 
-#define DATE_INIT(date) date.mask = 0
+#define DATE_INIT(date) memset(&(date), 0, sizeof(date))
 #define DATE_SET(date, memb, m, val) \
  do { date . memb = val; date.mask |= m; } while (0)
 
