@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2000, 2001, 2003 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2000, 2001, 2003, 2005 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -11,9 +11,10 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.
 
-   You should have received a copy of the GNU Lesser General Public
-   License along with this library; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   You should have received a copy of the GNU Lesser General
+   Public License along with this library; if not, write to the
+   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301 USA */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -130,16 +131,16 @@ int _pop_apop            __P ((authority_t));
 static int pop_get_size        __P ((mailbox_t, off_t *));
 /* We use pop_top for retreiving headers.  */
 /* static int pop_header_read (header_t, char *, size_t, off_t, size_t *); */
-static int pop_body_fd         __P ((stream_t, int *, int *));
+static int pop_body_transport  __P ((stream_t, mu_transport_t *, mu_transport_t *));
 static int pop_body_size       __P ((body_t, size_t *));
 static int pop_body_lines      __P ((body_t, size_t *));
 static int pop_body_read       __P ((stream_t, char *, size_t, off_t, size_t *));
 static int pop_message_read    __P ((stream_t, char *, size_t, off_t, size_t *));
 static int pop_message_size    __P ((message_t, size_t *));
-static int pop_message_fd      __P ((stream_t, int *, int *));
+static int pop_message_transport __P ((stream_t, mu_transport_t *, mu_transport_t *));
 static int pop_top             __P ((header_t, char *, size_t, off_t, size_t *));
 static int pop_retr            __P ((pop_message_t, char *, size_t, off_t, size_t *));
-static int pop_get_fd          __P ((pop_message_t, int *));
+static int pop_get_transport2   __P ((pop_message_t, mu_transport_t *, mu_transport_t *));
 static int pop_get_attribute   __P ((attribute_t, int *));
 static int pop_set_attribute   __P ((attribute_t, int));
 static int pop_unset_attribute __P ((attribute_t, int));
@@ -932,7 +933,7 @@ pop_get_message (mailbox_t mbox, size_t msgno, message_t *pmsg)
     /* Help for the readline()s  */
     stream_setbufsiz (stream, 128);
     stream_set_read (stream, pop_message_read, msg);
-    stream_set_fd (stream, pop_message_fd, msg);
+    stream_set_get_transport2 (stream, pop_message_transport, msg);
     message_set_stream (msg, stream, mpm);
     message_set_size (msg, pop_message_size, mpm);
   }
@@ -982,7 +983,7 @@ pop_get_message (mailbox_t mbox, size_t msgno, message_t *pmsg)
     /* Helps for the readline()s  */
     stream_setbufsiz (stream, 128);
     stream_set_read (stream, pop_body_read, body);
-    stream_set_fd (stream, pop_body_fd, body);
+    stream_set_get_transport2 (stream, pop_body_transport, body);
     body_set_size (body, pop_body_size, msg);
     body_set_lines (body, pop_body_lines, msg);
     body_set_stream (body, stream, msg);
@@ -1305,7 +1306,7 @@ pop_message_size (message_t msg, size_t *psize)
   CLEAR_STATE (mpd);
 
   if (status != 2)
-    status = EINVAL;
+    status = MU_ERR_PARSE;
 
   /* The size of the message is with the extra '\r' octet for everyline.
      Substract to get, hopefully, a good count.  */
@@ -1414,39 +1415,28 @@ pop_unset_attribute (attribute_t attr, int flags)
 
 /* Stub to call the fd from body object.  */
 static int
-pop_body_fd (stream_t stream, int *pfd, int *pfd1)
+pop_body_transport (stream_t stream, mu_transport_t *ptr, mu_transport_t *ptr2)
 {
-  if (pfd1)
-    return ENOSYS;
-  else
-    {
-      body_t body = stream_get_owner (stream);
-      message_t msg = body_get_owner (body);
-      pop_message_t mpm = message_get_owner (msg);
-      return pop_get_fd (mpm, pfd);
-    }
+  body_t body = stream_get_owner (stream);
+  message_t msg = body_get_owner (body);
+  pop_message_t mpm = message_get_owner (msg);
+  return pop_get_transport2 (mpm, ptr, ptr2);
 }
 
 /* Stub to call the fd from message object.  */
 static int
-pop_message_fd (stream_t stream, int *pfd, int *pfd2)
+pop_message_transport (stream_t stream, mu_transport_t *ptr, mu_transport_t *ptr2)
 {
-  if (pfd2)
-    return ENOSYS;
-  else
-    {
-      message_t msg = stream_get_owner (stream);
-      pop_message_t mpm = message_get_owner (msg);
-      return pop_get_fd (mpm, pfd);
-    }
+  message_t msg = stream_get_owner (stream);
+  pop_message_t mpm = message_get_owner (msg);
+  return pop_get_transport2 (mpm, ptr, ptr2);
 }
 
-/* Finally return the fd.  */
 static int
-pop_get_fd (pop_message_t mpm, int *pfd)
+pop_get_transport2 (pop_message_t mpm, mu_transport_t *ptr, mu_transport_t *ptr2)
 {
   if (mpm && mpm->mpd && mpm->mpd->mbox)
-	return stream_get_fd (mpm->mpd->mbox->stream, pfd);
+	return stream_get_transport2 (mpm->mpd->mbox->stream, ptr, ptr2);
   return EINVAL;
 }
 
@@ -1535,7 +1525,7 @@ pop_uidl (message_t msg, char *buffer, size_t buflen, size_t *pnwriten)
   status = sscanf (mpd->buffer, "+OK %d %127s\n", &num, uniq);
   if (status != 2)
     {
-      status = EINVAL;
+      status = MU_ERR_PARSE;
       buflen = 0;
     }
   else
@@ -2076,7 +2066,7 @@ pop_get_timestamp (pop_data_t mpd)
 static int
 pop_get_md5 (pop_data_t mpd)
 {
-  MD5_CTX md5context;
+  struct md5_ctx md5context;
   unsigned char md5digest[16];
   char digest[64]; /* Really it just has to be 32 + 1(null).  */
   char *tmp;
@@ -2087,10 +2077,11 @@ pop_get_md5 (pop_data_t mpd)
   if (timestamp == NULL)
     return EINVAL;
 
-  MD5Init (&md5context);
-  MD5Update (&md5context, (unsigned char *)timestamp, strlen (timestamp));
-  MD5Update (&md5context, (unsigned char *)mpd->passwd, strlen (mpd->passwd));
-  MD5Final (md5digest, &md5context);
+  md5_init_ctx (&md5context);
+  md5_process_bytes (timestamp, strlen (timestamp), &md5context);
+  md5_process_bytes (mpd->passwd, strlen (mpd->passwd), &md5context);
+  md5_finish_ctx (&md5context, md5digest);
+  
   for (tmp = digest, n = 0; n < 16; n++, tmp += 2)
     sprintf (tmp, "%02x", md5digest[n]);
   *tmp = '\0';
