@@ -14,7 +14,8 @@
 
    You should have received a copy of the GNU General Public License
    along with GNU Mailutils; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+   MA 02110-1301 USA */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -34,7 +35,9 @@ static char doc[] = N_("GNU messages -- count the number of messages in a mailbo
 static char args_doc[] = N_("[mailbox...]");
 
 static struct argp_option options[] = {
-  { NULL,         0, NULL,  0,  N_("messages specific switches:"), 0},
+  { NULL,         0, NULL,  0,
+    /* TRANSLATORS: 'messages' is a program name. Do not translate it! */
+    N_("messages specific switches:"), 0},
   {"quiet",	'q',	0,	0,	N_("Only display number of messages")},
   {"silent",	's',	0,	0,	N_("Same as -q")},
   { 0 }
@@ -135,8 +138,12 @@ messages_count (const char *box)
   status =  mailbox_create_default (&mbox, box);
   if (status != 0)
     {
-      mu_error (_("Couldn't create mailbox <%s>: %s."),
-		box ? box : _("default"), mu_strerror (status));
+      if (box)
+	mu_error (_("Could not create mailbox `%s': %s"),
+		  box, mu_strerror (status));
+      else
+	mu_error (_("Could not create default mailbox: %s"),
+		  mu_strerror (status));
       return -1;
     }
 
@@ -146,7 +153,7 @@ messages_count (const char *box)
   status =  mailbox_open (mbox, MU_STREAM_READ);
   if (status != 0)
     {
-      mu_error (_("Couldn't open mailbox <%s>: %s."),
+      mu_error (_("Could not open mailbox `%s': %s"),
 		box, mu_strerror (status));
       return -1;
     }
@@ -154,7 +161,7 @@ messages_count (const char *box)
   status = mailbox_messages_count (mbox, &count);
   if (status != 0)
     {
-      mu_error (_("Couldn't count messages in <%s>: %s."),
+      mu_error (_("Could not count messages in mailbox `%s': %s"),
 		box, mu_strerror (status));
       return -1;
     }
@@ -167,7 +174,7 @@ messages_count (const char *box)
   status = mailbox_close (mbox);
   if (status != 0)
     {
-      mu_error (_("Couldn't close <%s>: %s."),
+      mu_error (_("Could not close `%s': %s"),
 		box, mu_strerror (status));
       return -1;
     }
