@@ -13,16 +13,19 @@
 
    You should have received a copy of the GNU General Public License
    along with GNU Mailutils; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+   MA 02110-1301 USA */
 
 /* MH annotate command */
 
 #include <mh.h>
 
 const char *program_version = "anno (" PACKAGE_STRING ")";
-static char doc[] = N_("GNU MH anno\v"
-"Options marked with `*' are not yet implemented.\n"
-"Use -help to obtain the list of traditional MH options.");
+/* TRANSLATORS: Please, preserve the vertical tabulation (^K character)
+   in this message */
+static char doc[] = N_("GNU MH anno\v\
+Options marked with `*' are not yet implemented.\n\
+Use -help to obtain the list of traditional MH options.");
 static char args_doc[] = N_("[msg [msg...]]");
 
 /* GNU options */
@@ -113,11 +116,12 @@ main (int argc, char **argv)
   int index;
   mailbox_t mbox;
   mh_msgset_t msgset;
+  size_t len;
   
   mu_init_nls ();
 
   mu_argp_init (program_version, NULL);
-  mh_argp_parse (argc, argv, 0, options, mh_option, args_doc, doc,
+  mh_argp_parse (&argc, &argv, 0, options, mh_option, args_doc, doc,
 		 opt_handler, NULL, &index);
 
   mbox = mh_open_folder (current_folder, 0);
@@ -134,6 +138,10 @@ main (int argc, char **argv)
   if (!anno_text && !anno_date)
     exit (0);
 
+  len = strlen (component);
+  if (len > 0 && component[len-1] == ':')
+    component[len-1] = 0;
+  
   argc -= index;
   argv += index;
   
