@@ -13,7 +13,8 @@
 
    You should have received a copy of the GNU General Public License
    along with GNU Mailutils; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+   MA 02110-1301 USA */
 
 /* MH folder command */
 
@@ -33,8 +34,10 @@
 #include <obstack.h>
 
 const char *program_version = "folder (" PACKAGE_STRING ")";
-static char doc[] = N_("GNU MH folder\v"
-"Use -help to obtain the list of traditional MH options.");
+/* TRANSLATORS: Please, preserve the vertical tabulation (^K character)
+   in this message */
+static char doc[] = N_("GNU MH folder\v\
+Use -help to obtain the list of traditional MH options.");
 static char args_doc[] = N_("[action] [msg]");
 
 static struct argp_option options[] = {
@@ -104,7 +107,10 @@ static int action_pop ();
 static folder_action action = action_print;
 
 int show_all = 0; /* List all folders. Raised by --all switch */
-int create_flag = 0; /* Create non-existent folders (--create) */
+int create_flag = -1; /* Create non-existent folders (--create).
+		         -1: Prompt before creating
+		          0: Do not create
+		          1: Always create without prompting */
 int fast_mode = 0; /* Fast operation mode. (--fast) */
 int print_header = 0; /* Display the header line (--header) */
 int recurse = 0; /* Recurse sub-folders */
@@ -280,15 +286,27 @@ _scan (const char *name, int depth)
   
   dir = opendir (name);
 
-  if (!dir && errno == ENOENT && create_flag)
+  if (!dir && errno == ENOENT)
     {
-      mh_check_folder (name, 0);
-      dir = opendir (name);
+      if (create_flag)
+	{
+	  if (mh_check_folder (name, create_flag == -1))
+	    {
+	      push_folder = 0;
+	      return;
+	    }
+	  dir = opendir (name);
+	}
+      else
+	{
+	  push_folder = 0;
+	  return;
+	}
     }
 
   if (!dir)
     {
-      mh_error (_("can't scan folder %s: %s"), name, strerror (errno));
+      mh_error (_("Cannot scan folder %s: %s"), name, strerror (errno));
       return;
     }
 
@@ -305,7 +323,7 @@ _scan (const char *name, int depth)
 	{
 	  asprintf (&p, "%s/%s", name, entry->d_name);
 	  if (stat (p, &st) < 0)
-	    mh_error (_("can't stat %s: %s"), p, strerror (errno));
+	    mh_error (_("Cannot stat %s: %s"), p, strerror (errno));
 	  else if (S_ISDIR (st.st_mode))
 	    {
 	      info.others++;
@@ -528,7 +546,7 @@ main (int argc, char **argv)
   mu_init_nls ();
 
   mu_argp_init (program_version, NULL);
-  mh_argp_parse (argc, argv, 0, options, mh_option, args_doc, doc,
+  mh_argp_parse (&argc, &argv, 0, options, mh_option, args_doc, doc,
 		 opt_handler, NULL, &index);
 
   /* If  folder  is invoked by a name ending with "s" (e.g.,  folders),
@@ -547,7 +565,7 @@ main (int argc, char **argv)
     }
   else if (argc - index > 1)
     {
-      mh_error (_("too many arguments"));
+      mh_error (_("Too many arguments"));
       exit (1);
     }
   
