@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2000, 2001, 2002 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2000, 2001, 2002, 2004 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -13,7 +13,8 @@
 
    You should have received a copy of the GNU General Public License
    along with GNU Mailutils; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+   MA 02110-1301 USA */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -45,6 +46,7 @@
 #include <mailutils/debug.h>
 #include <mailutils/mailer.h>
 #include <mailutils/envelope.h>
+#include <mailutils/mime.h>
 
 #include <mu_asprintf.h>
 #include <getline.h>
@@ -63,7 +65,7 @@ extern char *strchrnul __P((const char *s, int c_in));
 #define MH_CONTEXT_FILE "context"
 #define DEFAULT_ALIAS_FILE MHLIBDIR "/MailAliases"
 
-#define is_true(arg) ((arg)==NULL||(arg)[0] == 'y')
+#define is_true(arg) ((arg) == NULL||mu_true_answer_p (arg) == 1)
 
 enum mh_opcode
 {
@@ -315,6 +317,7 @@ char *mh_draft_name __P((void));
 char *mh_create_message_id __P((int));
 int mh_whom __P((char *filename, int check));
 void mh_set_reply_regex __P((const char *str));
+int mh_decode_2047 __P((char *text, char **decoded_text));
 
 int mh_alias_read __P((char *name, int fail));
 int mh_alias_get __P((char *name, list_t *return_list));
@@ -348,4 +351,5 @@ void mh_comp_draft __P((char *formfile, char *defformfile, char *draftfile));
 int check_draft_disposition __P((struct mh_whatnow_env *wh, int use_draft));
 
 void ali_parse_error __P((char *fmt, ...));
+void ali_verbatim __P((int enable));
 
