@@ -13,7 +13,8 @@
 
    You should have received a copy of the GNU General Public License
    along with GNU Mailutils; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+   MA 02110-1301 USA */
 
 #include <mh.h>
 
@@ -34,7 +35,7 @@ addrcp (list_t *list, char *addr, int isbcc)
   p->isbcc = isbcc;
   if (!*list && (rc = list_create (list)))
     {
-      mh_error (_("can't create list: %s"), mu_strerror (rc));
+      mh_error (_("Cannot create list: %s"), mu_strerror (rc));
       exit (1);
     }
   list_append (*list, p);
@@ -224,7 +225,7 @@ mh_whom (char *filename, int check)
   ctx = mh_context_create (filename, 1);
   if (mh_context_read (ctx))
     {
-      mh_error (_("malformed message"));
+      mh_error (_("Malformed message"));
       rc = -1;
     }
   else
