@@ -13,7 +13,8 @@
 
    You should have received a copy of the GNU General Public License
    along with GNU Mailutils; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+   MA 02110-1301 USA */
 
 /* MH pick command */
 
@@ -26,9 +27,11 @@
 #include <obstack.h>
 
 const char *program_version = "pick (" PACKAGE_STRING ")";
-static char doc[] = N_("GNU MH pick\v"
-"Options marked with `*' are not yet implemented.\n"
-"Use -help to obtain the list of traditional MH options.");
+/* TRANSLATORS: Please, preserve the vertical tabulation (^K character)
+   in this message */
+static char doc[] = N_("GNU MH pick\v\
+Options marked with `*' are not yet implemented.\n\
+Use -help to obtain the list of traditional MH options.");
 static char args_doc[] = N_("[messages]");
 
 /* GNU options */
@@ -135,7 +138,7 @@ add_sequence (char *name)
 {
   if (!seq_list && list_create (&seq_list))
     {
-      mh_error (_("can't create sequence list"));
+      mh_error (_("Cannot create sequence list"));
       exit (1);
     }
   list_append (seq_list, name);
@@ -262,7 +265,7 @@ opt_handler (int key, char *arg, void *unused, struct argp_state *state)
       s = state->argv[state->next - 1];
       if (memcmp (s, "--", 2))
 	{
-	  argp_error (state, _("invalid option -- %s"), s);
+	  argp_error (state, _("Invalid option -- %s"), s);
 	  exit (1);
 	}
       p = strchr (s, '=');
@@ -275,7 +278,7 @@ opt_handler (int key, char *arg, void *unused, struct argp_state *state)
 	{
 	  if (state->next == state->argc)
 	    {
-	      mh_error (_("invalid option -- %s"), s);
+	      mh_error (_("Invalid option -- %s"), s);
 	      exit (1);
 	    }
 	  p = state->argv[state->next++];
@@ -348,7 +351,7 @@ main (int argc, char **argv)
   flags = mh_interactive_mode_p () ? 0 : ARGP_NO_ERRS;
   mu_init_nls ();
   mu_argp_init (program_version, NULL);
-  mh_argp_parse (argc, argv, flags, options, mh_option,
+  mh_argp_parse (&argc, &argv, flags, options, mh_option,
 		 args_doc, doc, opt_handler, NULL, &index);
   if (pick_parse (lexlist))
     return 1;
