@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2002,2003 Free Software Foundation, Inc.
+   Copyright (C) 2002,2003,2004 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -13,7 +13,8 @@
 
    You should have received a copy of the GNU General Public License
    along with GNU Mailutils; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+   MA 02110-1301 USA */
 
 /* MH refile command */
 
@@ -39,12 +40,12 @@ static struct argp_option options[] = {
   {"draft",   ARG_DRAFT, NULL, 0,
    N_("Use <mh-dir>/draft as the source message")},
   {"copy",    ARG_LINK, N_("BOOL"), OPTION_ARG_OPTIONAL,
-   N_("Preserve the source folder copy.")},
+   N_("Preserve the source folder copy")},
   {"link",    0, NULL, OPTION_ALIAS, NULL},
   {"preserve", ARG_PRESERVE, N_("BOOL"), OPTION_ARG_OPTIONAL,
    N_("* Try to preserve message sequence numbers")},
   {"source", ARG_SOURCE, N_("FOLDER"), 0,
-   N_("Specify source folder. FOLDER will become the current folder after the program exits.")},
+   N_("Specify source folder. FOLDER will become the current folder after the program exits")},
   {"src", 0, NULL, OPTION_ALIAS, NULL},
   {"file", ARG_FILE, N_("FILE"), 0, N_("Use FILE as the source message")},
   {"license", ARG_LICENSE, 0,      0,
@@ -73,7 +74,7 @@ add_folder (const char *folder)
 {
   if (!folder_name_list && list_create (&folder_name_list))
     {
-      mh_error (_("can't create folder list"));
+      mh_error (_("Cannot create folder list"));
       exit (1);
     }
   list_append (folder_name_list, strdup (folder));
@@ -86,19 +87,19 @@ open_folders ()
 
   if (!folder_name_list)
     {
-      mh_error (_("no folder specified"));
+      mh_error (_("No folder specified"));
       exit (1);
     }
 
   if (list_create (&folder_mbox_list))
     {
-      mh_error (_("can't create folder list"));
+      mh_error (_("Cannot create folder list"));
       exit (1);
     }
 
-  if (iterator_create (&itr, folder_name_list))
+  if (list_get_iterator (folder_name_list, &itr))
     {
-      mh_error (_("can't create iterator"));
+      mh_error (_("Cannot create iterator"));
       exit (1);
     }
 
@@ -121,9 +122,9 @@ enumerate_folders (void (*f) __P((void *, mailbox_t)), void *data)
 {
   iterator_t itr;
 
-  if (iterator_create (&itr, folder_mbox_list))
+  if (list_get_iterator (folder_mbox_list, &itr))
     {
-      mh_error (_("can't create iterator"));
+      mh_error (_("Cannot create iterator"));
       exit (1);
     }
 
@@ -197,7 +198,7 @@ refile_folder (void *data, mailbox_t mbox)
   rc = mailbox_append_message (mbox, msg);
   if (rc)
     {
-      mh_error (_("error appending message: %s"), mu_strerror (rc));
+      mh_error (_("Error appending message: %s"), mu_strerror (rc));
       exit (1);
     }
 }
@@ -257,7 +258,7 @@ main (int argc, char **argv)
       
       if (argc > 0)
 	{
-	  mh_error (_("both message set and source file given"));
+	  mh_error (_("Both message set and source file given"));
 	  exit (1);
 	}
       msg = mh_file_to_message (mu_path_folder_dir, source_file);
