@@ -13,7 +13,8 @@
 
    You should have received a copy of the GNU General Public License
    along with GNU Mailutils; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+   MA 02110-1301 USA */
 
 /* MH rmf command */
 
@@ -124,7 +125,7 @@ rmf (const char *name)
 
   if (!dir)
     {
-      mh_error (_("can't scan folder %s: %s"), name, strerror (errno));
+      mh_error (_("Cannot scan folder %s: %s"), name, strerror (errno));
       return 1;
     }
 
@@ -143,7 +144,7 @@ rmf (const char *name)
       asprintf (&p, "%s/%s", name, entry->d_name);
       if (stat (p, &st) < 0)
 	{
-	  mh_error (_("can't stat %s: %s"), p, strerror (errno));
+	  mh_error (_("Cannot stat %s: %s"), p, strerror (errno));
 	}
       else if (S_ISDIR (st.st_mode))
 	{
@@ -160,7 +161,7 @@ rmf (const char *name)
 	{
 	  if (unlink (p))
 	    {
-	      mh_error (_("can't unlink %s: %s"), p, strerror (errno));
+	      mh_error (_("Cannot unlink %s: %s"), p, strerror (errno));
 	      failures++;
 	    }
 	}
