@@ -13,7 +13,8 @@
 
    You should have received a copy of the GNU General Public License
    along with GNU Mailutils; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+   MA 02110-1301 USA */
 
 #include "pop3d.h"
 
@@ -153,27 +154,20 @@ int
 pop3d_init_tls_server ()
 {
   stream_t stream;
-  int in_fd;
-  int out_fd;
   int rc;
-  
-  if (stream_get_fd (istream, &in_fd)
-      || stream_get_fd (ostream, &out_fd))
-    return 0;
-  rc = tls_stream_create (&stream, in_fd, out_fd, 0);
+ 
+  rc = tls_stream_create (&stream, istream, ostream, 0);
   if (rc)
     return 0;
 
   if (stream_open (stream))
     {
-      char *p;
+      const char *p;
       stream_strerror (stream, &p);
       syslog (LOG_ERR, _("cannot open TLS stream: %s"), p);
       return 0;
     }
   
-  stream_destroy (&istream, stream_get_owner (istream));
-  stream_destroy (&ostream, stream_get_owner (ostream));
   istream = ostream = stream;
   return 1;
 }
@@ -227,11 +221,11 @@ pop3d_outf (const char *fmt, ...)
   free (buf);
   if (rc)
     {
-      char *p;
+      const char *p;
 
       if (stream_strerror (ostream, &p))
 	p = strerror (errno);
-      syslog (LOG_ERR, _("write failed: %s"), p);
+      syslog (LOG_ERR, _("Write failed: %s"), p);
       pop3d_abquit (ERR_NO_OFILE);
     }
 }
@@ -250,11 +244,11 @@ pop3d_readline (char *buffer, size_t size)
 
   if (rc)
     {
-      char *p;
+      const char *p;
 
       if (stream_strerror (ostream, &p))
 	p = strerror (errno);
-      syslog (LOG_ERR, _("read failed: %s"), p);
+      syslog (LOG_ERR, _("Read failed: %s"), p);
       pop3d_abquit (ERR_NO_OFILE);
     }
   else if (nbytes == 0)
@@ -269,3 +263,44 @@ pop3d_readline (char *buffer, size_t size)
   /* Caller should not free () this ... should we strdup() then?  */
   return buffer;
 }
+
+
+/* Handling of the deletion marks */
+
+void
+pop3d_mark_deleted (attribute_t attr)
+{
+  attribute_set_userflag (attr, POP3_ATTRIBUTE_DELE);
+}
+
+int
+pop3d_is_deleted (attribute_t attr)
+{
+  return attribute_is_deleted (attr)
+         || attribute_is_userflag (attr, POP3_ATTRIBUTE_DELE);
+}
+
+void
+pop3d_unset_deleted (attribute_t attr)
+{
+  if (attribute_is_userflag (attr, POP3_ATTRIBUTE_DELE))
+    attribute_unset_userflag (attr, POP3_ATTRIBUTE_DELE);
+}
+
+void
+pop3d_undelete_all ()
+{
+  size_t i;
+  size_t total = 0;
+
+  mailbox_messages_count (mbox, &total);
+
+  for (i = 1; i <= total; i++)
+    {
+       message_t msg = NULL;
+       attribute_t attr = NULL;
+       mailbox_get_message (mbox, i, &msg);
+       message_get_attribute (msg, &attr);
+       attribute_unset_deleted (attr);
+    }
+}
