@@ -1,5 +1,6 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2000, 2001, 2002, 2003,
+   2004, 2005 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -13,7 +14,8 @@
 
    You should have received a copy of the GNU General Public License
    along with GNU Mailutils; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+   MA 02110-1301 USA */
 
 #ifndef _POP3D_H
 #define _POP3D_H	1
@@ -91,7 +93,10 @@ extern void login_delay_capa __P((void));
 #endif
 
 /* Minimum advertise retention time for messages.  */
-extern int expire;
+extern time_t expire;
+extern int expire_on_exit;
+
+#define EXPIRE_NEVER ((time_t)-1)
 
 /* Size of the MD5 digest for APOP */
 #define APOP_DIGEST	70
@@ -128,7 +133,7 @@ extern int expire;
 #include <grp.h>
 #include <syslog.h>
 #include <ctype.h>
-#include "md5.h"
+#include <md5.h>
 #ifdef HAVE_STRINGS_H
 # include <strings.h>
 #endif
@@ -173,6 +178,7 @@ extern int expire;
 #define POP3_ATTRIBUTE_DELE 0x0001
 #define POP3_ATTRIBUTE_RETR 0x0010
 
+#define INITIAL        -1
 #define AUTHORIZATION	0
 #define TRANSACTION	1
 #define UPDATE		2
@@ -200,10 +206,11 @@ extern int expire;
 
 extern mailbox_t mbox;
 extern int state;
+extern int initial_state;
 extern char *username;
 extern char *maildir;
 extern char *md5shared;
-extern volatile size_t children;
+extern size_t children;
 extern struct daemon_param daemon_param;
 extern int debug_mode;
 #ifdef WITH_TLS
@@ -262,4 +269,7 @@ extern void pop3d_mark_retr __P((attribute_t attr));
 extern int pop3d_is_retr __P((attribute_t attr));
 extern void pop3d_unmark_retr __P((attribute_t attr));
 
+extern void expire_mark_message __P((message_t msg, char **value));
+
+
 #endif /* _POP3D_H */
