@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2000, 2001, 2002 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2000, 2001, 2002, 2005 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -13,7 +13,8 @@
 
    You should have received a copy of the GNU General Public License
    along with GNU Mailutils; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+   MA 02110-1301 USA */
 
 #include "pop3d.h"
 #include <mailutils/argcv.h>
@@ -28,6 +29,8 @@ int db_make (char *input_name, char *output_name);
 #define ACT_LIST    3
 #define ACT_CHPASS  4
 
+static int permissions = 0600;
+
 struct action_data {
   int action;
   char *input_name;
@@ -68,6 +71,7 @@ static struct argp_option options[] =
   { "modify", 'm', 0, 0, N_("Modify user's record (change password)"), 1 },
   { "delete", 'd', 0, 0, N_("Delete user's record"), 1 },
   { "list", 'l', 0, 0, N_("List the contents of DBM file"), 1 },
+  { "create", 'c', 0, 0, N_("Create the DBM from a plaintext file"), 1 },
 
   { NULL, 0, NULL, 0,
     N_("Default action is:\n"
@@ -79,6 +83,7 @@ static struct argp_option options[] =
   { "output", 'o', N_("FILE"), 0, N_("Direct output to file"), 3 },
   { "password", 'p', N_("STRING"), 0, N_("Specify user's password"), 3 },
   { "user", 'u', N_("USERNAME"), 0, N_("Specify user name"), 3 },
+  { "permissions", 'P', N_("PERM"), 0, N_("Force given permissions on the database"), 3 },
   { NULL, }
 };
 
@@ -97,6 +102,24 @@ static const char *popauth_argp_capa[] = {
   NULL
 };
 
+static void
+set_db_perms (struct argp_state *astate, char *opt, int *pperm)
+{
+  int perm = 0;
+   
+  if (isdigit(opt[0]))
+    {
+      char *p;
+      perm = strtoul (opt, &p, 8);
+      if (*p)
+	{
+	  argp_error (astate, _("Invalid octal number: %s"), opt);
+	  exit (1);
+	}
+    }
+  *pperm = perm;
+}
+
 static error_t
 popauth_parse_opt (int key, char *arg, struct argp_state *astate)
 {
@@ -112,7 +135,12 @@ popauth_parse_opt (int key, char *arg, struct argp_state *astate)
       check_action (ap->action);
       ap->action = ACT_ADD;
       break;
-	
+
+    case 'c':
+      check_action (ap->action);
+      ap->action = ACT_CREATE;
+      break;
+      
     case 'l':
       check_action (ap->action);
       ap->action = ACT_LIST;
@@ -124,7 +152,7 @@ popauth_parse_opt (int key, char *arg, struct argp_state *astate)
       break;
 	  
     case 'p':
-      ap->passwd = optarg;
+      ap->passwd = arg;
       break;
       
     case 'm':
@@ -133,17 +161,21 @@ popauth_parse_opt (int key, char *arg, struct argp_state *astate)
       break;
 	
     case 'f':
-      ap->input_name = optarg;
+      ap->input_name = arg;
       break;
 	  
     case 'o':
-      ap->output_name = optarg;
+      ap->output_name = arg;
       break;
 	
     case 'u':
-      ap->username = optarg;
+      ap->username = arg;
       break;
 	
+    case 'P':
+      set_db_perms (astate, arg, &permissions);
+      break;
+      
     case ARGP_KEY_FINI:
       if (ap->action == -1)
 	{
@@ -153,7 +185,8 @@ popauth_parse_opt (int key, char *arg, struct argp_state *astate)
 	  else
 	    ap->action = ACT_CHPASS;
 	}
-      
+      break;
+
     default:
       return ARGP_ERR_UNKNOWN;
     }
@@ -200,10 +233,10 @@ check_user_perm (int action, struct action_data *ap)
       if (ap->action == ACT_ADD)
 	{
 	  DBM_FILE db;
-	  if (mu_dbm_open (ap->input_name, &db, MU_STREAM_CREAT, 0600))
+	  if (mu_dbm_open (ap->input_name, &db, MU_STREAM_CREAT, permissions))
 	    {
-	      mu_error (_("can't create %s: %s"),
-			ap->input_name, strerror (errno));
+	      mu_error (_("Cannot create %s: %s"),
+			ap->input_name, mu_strerror (errno));
 	      exit (1);
 	    }
 	  mu_dbm_close (db);
@@ -211,7 +244,7 @@ check_user_perm (int action, struct action_data *ap)
 	}
       else
 	{
-	  mu_error (_("can't stat %s: %s"), ap->input_name, strerror (errno));
+	  mu_error (_("Cannot stat %s: %s"), ap->input_name, mu_strerror (errno));
 	  exit (1);
 	}
     }
@@ -247,9 +280,9 @@ action_list (struct action_data *ap)
   DBM_DATUM contents;
   
   check_user_perm (ACT_LIST, ap);
-  if (mu_dbm_open (ap->input_name, &db, MU_STREAM_READ, 0600))
+  if (mu_dbm_open (ap->input_name, &db, MU_STREAM_READ, permissions))
     {
-      mu_error (_("can't open %s: %s"), ap->input_name, strerror (errno));
+      mu_error (_("Cannot open %s: %s"), ap->input_name, mu_strerror (errno));
       return 1;
     }
   
@@ -258,7 +291,7 @@ action_list (struct action_data *ap)
       fp = fopen (ap->output_name, "w");
       if (!fp)
 	{
-	  mu_error (_("can't create %s: %s"), ap->output_name, strerror (errno));
+	  mu_error (_("Cannot create %s: %s"), ap->output_name, mu_strerror (errno));
 	  return 1;
 	}
     }
@@ -273,7 +306,7 @@ action_list (struct action_data *ap)
       MU_DATUM_SIZE (key) = strlen (ap->username);
       if (mu_dbm_fetch (db, key, &contents))
 	{
-	  mu_error (_("no such user: %s"), ap->username);
+	  mu_error (_("No such user: %s"), ap->username);
 	}
       else
 	fprintf (fp, "%.*s: %.*s\n",
@@ -320,7 +353,7 @@ action_create (struct action_data *ap)
       fp = fopen (ap->input_name, "r");
       if (!fp)
 	{
-	  mu_error (_("can't open %s: %s"), ap->input_name, strerror (errno));
+	  mu_error (_("Cannot open %s: %s"), ap->input_name, mu_strerror (errno));
 	  return 1;
 	}
     }
@@ -332,9 +365,9 @@ action_create (struct action_data *ap)
   
   if (!ap->output_name)
     ap->output_name = APOP_PASSFILE;
-  if (mu_dbm_open (ap->output_name, &db, MU_STREAM_CREAT, 0600))
+  if (mu_dbm_open (ap->output_name, &db, MU_STREAM_CREAT, permissions))
     {
-      mu_error (_("can't create %s: %s"), ap->output_name, strerror (errno));
+      mu_error (_("Cannot create %s: %s"), ap->output_name, mu_strerror (errno));
       return 1;
     }
 
@@ -377,7 +410,7 @@ action_create (struct action_data *ap)
       MU_DATUM_SIZE (contents) = strlen (argv[2]);
 
       if (mu_dbm_insert (db, key, contents, 1))
-	mu_error (_("%s:%d: can't store datum"), ap->input_name, line);
+	mu_error (_("%s:%d: cannot store datum"), ap->input_name, line);
 
       argcv_free (argc, argv);
     }
@@ -392,9 +425,9 @@ open_io (int action, struct action_data *ap, DBM_FILE *db, int *not_owner)
   int rc = check_user_perm (action, ap);
   if (not_owner)
     *not_owner = rc;
-  if (mu_dbm_open (ap->input_name, db, MU_STREAM_RDWR, 0600))
+  if (mu_dbm_open (ap->input_name, db, MU_STREAM_RDWR, permissions))
     {
-      mu_error (_("can't open %s: %s"), ap->input_name, strerror (errno));
+      mu_error (_("Cannot open %s: %s"), ap->input_name, mu_strerror (errno));
       return 1;
     }
   return 0;
@@ -414,6 +447,8 @@ fill_pass (struct action_data *ap)
 	if (!p)
 	  exit (1);
 	ap->passwd = strdup (p);
+	/* TRANSLATORS: Please try to format this string so that it has
+	   the same length as the translation of 'Password:' above */
 	p = getpass (_("Confirm :"));
 	if (strcmp (ap->passwd, p) == 0)
 	  break;
@@ -432,7 +467,7 @@ action_add (struct action_data *ap)
   
   if (!ap->username)
     {
-      mu_error (_("missing username to add"));
+      mu_error (_("Missing username to add"));
       return 1;
     }
 
@@ -450,7 +485,7 @@ action_add (struct action_data *ap)
 
   rc = mu_dbm_insert (db, key, contents, 1);
   if (rc)
-    mu_error (_("can't store datum"));
+    mu_error (_("Cannot store datum"));
 
   mu_dbm_close (db);
   return rc;
@@ -465,7 +500,7 @@ action_delete (struct action_data *ap)
   
   if (!ap->username)
     {
-      mu_error (_("missing username to delete"));
+      mu_error (_("Missing username to delete"));
       return 1;
     }
 
@@ -477,7 +512,7 @@ action_delete (struct action_data *ap)
 
   rc = mu_dbm_delete (db, key);
   if (rc)
-    mu_error (_("can't remove record for %s"), ap->username);
+    mu_error (_("Cannot remove record for %s"), ap->username);
 
   mu_dbm_close (db);
   return rc;
@@ -497,7 +532,7 @@ action_chpass (struct action_data *ap)
 
   if (!ap->username)
     {
-      mu_error (_("missing username"));
+      mu_error (_("Missing username"));
       return 1;
     }
 
@@ -508,7 +543,7 @@ action_chpass (struct action_data *ap)
   MU_DATUM_SIZE (key) = strlen (ap->username);
   if (mu_dbm_fetch (db, key, &contents))
     {
-      mu_error (_("no such user: %s"), ap->username);
+      mu_error (_("No such user: %s"), ap->username);
       return 1;
     }
 
@@ -535,7 +570,7 @@ action_chpass (struct action_data *ap)
   MU_DATUM_SIZE (contents) = strlen (ap->passwd);
   rc = mu_dbm_insert (db, key, contents, 1);
   if (rc)
-    mu_error (_("can't replace datum"));
+    mu_error (_("Cannot replace datum"));
 
   mu_dbm_close (db);
   return rc;
